#
# spec file for package python-openstackclient
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-openstackclient
Version:        6.6.0
Release:        1.1
Summary:        OpenStack Command-line Client
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://docs.openstack.org/python-openstackclient
Source0:        https://files.pythonhosted.org/packages/source/p/python-openstackclient/python-openstackclient-6.6.0.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python3-cinderclient >= 3.3.0
BuildRequires:  python3-cliff >= 3.5.0
BuildRequires:  python3-ddt
BuildRequires:  python3-fixtures
BuildRequires:  python3-glanceclient
BuildRequires:  python3-keystoneclient >= 3.22.0
BuildRequires:  python3-novaclient >= 18.1.0
BuildRequires:  python3-openstacksdk >= 2.0.0
BuildRequires:  python3-os-client-config
BuildRequires:  python3-osc-lib >= 2.3.0
BuildRequires:  python3-oslotest
BuildRequires:  python3-osprofiler
BuildRequires:  python3-requests
BuildRequires:  python3-requests-mock
BuildRequires:  python3-setuptools
BuildRequires:  python3-stestr
BuildRequires:  python3-stevedore >= 2.0.1
BuildRequires:  python3-testtools
BuildRequires:  python3-wrapt
BuildArch:      noarch

%description
python-openstackclient is a unified command-line client for the OpenStack APIs.
It is a thin wrapper to the stock python-*client modules that implement the
actual REST API client actions.

%package -n python3-openstackclient
Summary:        OpenStack Command-line Client
Requires:       python3-Babel
Requires:       python3-cinderclient >= 3.3.0
Requires:       python3-cliff >= 3.5.0
Requires:       python3-glanceclient
Requires:       python3-heatclient
Requires:       python3-keystoneauth1
Requires:       python3-keystoneclient >= 3.22.0
Requires:       python3-novaclient >= 18.1.0
Requires:       python3-openstacksdk >= 2.0.0
Requires:       python3-osc-lib >= 2.3.0
Requires:       python3-oslo.i18n >= 3.15.3
Requires:       python3-oslo.utils
%if 0%{?suse_version}
Obsoletes:      python2-openstackclient < 4.0.0
%endif

%description -n python3-openstackclient
python-openstackclient is a unified command-line client for the OpenStack APIs.
It is a thin wrapper to the stock python-*client modules that implement the
actual REST API client actions.

This package contains the Python 3.x module.

%package -n python-openstackclient-doc
Summary:        Documentation for OpenStack Command-line Client
Group:          Documentation/HTML
# Some clients are commented out, since they have not been built yet
# TODO(jpena): uncomment them to enable their sections in the documentation
BuildRequires:  python3-Sphinx
#BuildRequires:  python3-aodhclient
#BuildRequires:  python3-barbicanclient
#BuildRequires:  python3-designateclient
#BuildRequires:  python3-heatclient
#BuildRequires:  python3-ironicclient
#BuildRequires:  python3-mistralclient
#BuildRequires:  python3-muranoclient
#BuildRequires:  python3-neutronclient
BuildRequires:  python3-openstackdocstheme
#BuildRequires:  python3-ironic-inspector-client
#BuildRequires:  python3-saharaclient
#BuildRequires:  python3-zaqarclient
BuildRequires:  python3-sphinxcontrib-apidoc

%description -n python-openstackclient-doc
python-openstackclient is a unified command-line client for the OpenStack APIs.
It is a thin wrapper to the stock python-*client modules that implement the
actual REST API client actions.
This package contains auto-generated documentation.

%prep
%autosetup -p1 -n python-openstackclient-6.6.0
%py_req_cleanup

%build
%{py3_build}

PBR_VERSION=6.6.0 %sphinx_build -b html doc/source doc/build/html
PBR_VERSION=6.6.0 %sphinx_build -b man doc/source doc/build/man
# remove the sphinx-build leftovers
rm -rf doc/build/html/.{doctrees,buildinfo}

%install
%{py3_install}
# man page
install -p -D -m 644 doc/build/man/openstack.1 %{buildroot}%{_mandir}/man1/openstack.1

%check
%{openstack_stestr_run}

%files -n python3-openstackclient
%doc README.rst
%license LICENSE
%{python3_sitelib}/openstackclient
%{python3_sitelib}/*.egg-info
%{_bindir}/openstack
%{_mandir}/man1/openstack.1.gz

%files -n python-openstackclient-doc
%license LICENSE
%doc doc/build/html

%changelog
* Thu May  2 2024 cloud-devel@suse.de
- update to version 6.6.0
  - reno: Update master for unmaintained/victoria
  - Update python classifier in setup.cfg
  - Adds CLI support for ``glance md-object-update``
  - Correct error message for "create server --wait"
  - compute: Fix formatting of 'server show'
  - tests: Remove unused flag
  - test: Ignore 'OS_' environment variables
  - doc: magnumclient provides a OSC plugin
  - network: Clarify purpose of default sg rules
  - Introduce `schema_version` in the federated attribute mapping API
  - doc: Remove RSD subcommand
  - Fix --use-prefix-delegation subnet create argument
  - image: Fix the default description of image visibility
  - doc: Remove Searchlight subcommands
  - Use CommandError, not SystemExit, to exit
  - Adding CLI command for ``glance member-get``
  - Remove unnecessary file
  - image: Trivial fixes
  - tests: Enable logging fixture
  - pre-commit: Bump linter versions
  - parseactions: Use ArgumentError, not ArgumentTypeError
  - Doc: Fix volume snapshot commands
  - Explicitly specify namespace fields for output
  - doc: Add manilaclient as a OSC plugin
  - compute: Address bug in shelve offload logic
  - [codespell] fix typos in doc,tests and help messages
  - tests: Remove prints
  - compute: Add 'server create --server-group' option
  - trivial: Fix typo
  - doc: Drop tripleoclient
  - Revert "Temporarily drop aodhclient from doc build"
  - reno: Update master for unmaintained/yoga
  - reno: Update master for unmaintained/xena
  - Add "hardware_offload_type" attribute to "port"
  - reno: Update master for unmaintained/wallaby
  - Fix clearing of dns_domain and description on a network by setting to empty strings
  - trivial: Don't ignore missing resources
  - Fix availability zone list command
  - trivial: Place positional opts last
* Sun Jan 14 2024 Dirk Müller <dmueller@suse.com>
- update to 6.4.0:
  * tests: Handle missing extensions in network tests
  * tests: Check for DHCP agents first in DHCP test
  * Adds command \`\`image metadef object delete\`\`
  * tests: Handle missing extensions in network tests
  * tests: Fix API extension check
  * tests: Centralise check for networking service
  * Adds command \`\`image metadef object list\`\`
  * Adds command \`\`image metadef object show\`\`
  * Add pagination helpers
  * Adds command \`\`image metadef object create\`\`
  * Update the docker image to python3.11
  * Update from storyboard to launchpad pt. 2
  * volume: Support same\_host, different\_host hint as list
  * Migrate resource filter commands to SDK
  * Removed start, end time format. Before fix, openstack usage
    list command resulted 'str' object has no attribute
    'isoformat' error
  * trivial: Make better use of argparse
  * volume: Add alias for volume type AZs
  * volume: Add aliases for common volume type props
  * volume: Allow filtering volume types by properties
  * Switch back to Launchpad
  * Add support for default security group rule CRUDs
  * Add "image metadef property set" command
  * Add "image metadef property delete" command
  * Add "image metadef property create" command
  * Add "image metadef property show" command
  * Add "image metadef property list" command
  * Migrate volume backend commands to SDK
  * image: Add support for cache commands
  * tests: Add compute v2 FakeClientMixin
  * tests: Use consistent shortcut to fake compute client
  * tests: Add volume v1, v2, v3 FakeClientMixin
  * tests: Use consistent shortcut to fake volume client
  * tests: Use central SDK client fake
  * Update branch regexes for tips jobs
  * Add is\_incremental to ListVolumeBackup
  * Update master for stable/2023.2
  * tests: Explicitly specify port fields for output
  * Remove use of oslo.utils
  * volume: Deprecate '--detailed' options
  * Propocol release versions properly
  * Fix ReleaseNotes build
  * tests: Add image v1, v2 FakeClientMixin
  * tests: Use consistent shortcut to fake image client
  * tests: Remove FakeImagev1Client, FakeImagev2Client
  * tests: Add network v2 FakeClientMixin
  * tests: Use consistent shortcut to fake network client
  * tests: Remove FakeNetworkV2Client
  * Remove project purge image commands
  * Migrate 'extension list' to SDK
  * Migrate 'availability zone list' to SDK
  * Fix "server create"command with --boot-from-volume
  * volume: Migrate 'volume group snapshot' commands to SDK
  * tox: Bump min\_version to 4.3.0
  * Add --skip-resource option to project cleanup
  * Add the flavor-id option to router create
  * Migrate backup commands to SDK
  * Check the default role list before adding a new one
  * Adding image stores info command
  * Adding \`\`image delete --store\`\` and \`\`image import
    info\`\` commands
  * Add a warning for resizing servers booted from volumes
  * Update the underlying python containers to "3.10-bookworm"
  * docs: Add examples of common auth methods
  * doc: Split image command documentation
  * Add image metadef resource type command 'list'
  * Migrate 'volume summary' command to SDK
  * tests: Use a new project for quota tests
  * Allow multiple \`--remove-tag\` in \`project set\`
  * Fix "access rule" commands to only use ID
  * tox: Disable E501
  * Neutron port hints
  * trivial: Remove duplicate definitions
  * Dropping the use of 'addFixedIp' server action
  * docs: Migrate volume commands to autoprogram-cliff
  * volume: Add 'volume qos set --no-property' option
  * volume: Make better use of argparse
  * volume: Add 'volume type set --private/--public'
  * compute: Fix bug with start/stop server
  * Allow server rebuild --wait for SHUTOFF servers
  * tests: Use SDK objects where expected
  * tests: Remove unnecessary nesting of compute resources
  * tests: Reorder compute fakes
  * Migrate 'volume revert' command to SDK
  * pre-commit: Enable black
  * Ignore black changes
  * Blacken everything else
  * Blacken openstackclient.api
  * Blacken openstack.common
  * Blacken openstackclient.image
  * Blacken openstackclient.object
  * Blacken openstackclient.identity
  * Blacken openstackclient.network
  * Blacken openstackclient.volume
  * Blacken openstackclient.compute
  * Use pre-commit for 'pep8' tox target, bump versions
  * Address pre-commit issues
  * compute: Generate SSH keypairs ourselves
  * Migrate 'server event \*' commands to SDK
  * Fix pep issue in the network service provider
  * Adding \`\`image import\`\` command
  * Silence warnings from openstacksdk
  * compute: Migrate 'reboot server' to SDK
  * Add an updated tips job running on py310
  * Show Network QoS rules one per line
  * "hypervisor list --matching" showed the wrong result
  * Docs: Update glance command mapping
  * Fix --security-group for port list
  * Update master for stable/2023.1
  * Add missing documentation for state options for "image set"
  * zuul: Merge osc-functional-devstack-base into only child
  * Wait for volume being available to set bootable or readonly
  * doc: Update nova command mapping
  * Deprecate positional args for 'volume group create'
  * Add options to create volume group from source
  * Add block storage manageable list commands
  * Add block storage cleanup command
  * Add block storage log level {list, set} commands
  * Add volume revert command
  * Add auto-approve option to project cleanup
  * volume: Remove duplication from 'consistency group create'
    opts
  * Move network trunk commands from python-neutronclient
  * Add volume summary command
  * tests: Use fake SDK Migration object
  * Excluding test code from coverage reports
  * Drop default from ask\_user\_yesno question
  * Fix tox v4 compatibility
  * Add plugin doc page for cyborg
  * Update 'host list' and 'host show' command to use sdk
  * Remove unused helpers for legacy novaclient
  * Switch server shelve, unshelve to SDK
  * compute: Switch server restore to SDK
  * Remove unnecessary 'self.methods'
  * Switch server start, server stop to SDK
  * Switch server lock, unlock to sdk
  * compute: 'server volume update' -> 'server volume set'
  * Switch server volume update to sdk
  * Switch list server volume to sdk
  * Switch server dump create to using sdk
  * Finish switching server migration to sdk
  * Fix server list error with --long and -c options
  * Create a functional test case for hypervisor list and show
  * Fix functional-tips job
  * Migrate hypervisor stats commands to SDK
  * Fix really long help strings
  * Fix parameter handling in server add fixed ip cmd
  * Use the SDK for server show
  * Add qos rule type filtering
  * Add image metadef namespace command
  * Updating the glanceclient reference doc
  * docs: Fix typos
  * compute: Allow users to manually specify bootable volumes
  * tests: Add test for multiple blocks devices
  * image: Fail if we can't find an image
  * image: Rename import
  * image: Add support for additional image import methods
  * Revert "Don't look up project by id if given id"
  * Use the SDK in server migration list
  * docs: Document how we manage API versions
  * docs: Describe common actions found in OSC
  * Use the compute SDK in server list
  * tests: Convert network tests to use 'parse\_output'
  * tests: Convert compute tests to use 'parse\_output'
  * tests: Convert identity tests to use 'parse\_output'
  * tests: Convert volume tests to use 'parse\_output'
  * tests: Convert image tests to use 'parse\_output'
  * Adding volume backend commands to volume v3
  * docs: Typo fix
  * docs: Small cleanup of human interface guide
  * Add test for creating volume from source
  * Change --size helptext to include backup
  * Add option to create volume from backup
  * Docstring fix for CreateVolumeAttachment class
  * Moved hypervisor to the SDK
  * image: Add 'image import' command
  * image: Add 'image stage' command
  * image: Simplify handling of data provided via stdin
  * image: Ignore '--progress' if providing image data from stdin
  * Add baremetal agent type list filtering
  * tests: Convert more functional tests to use 'parse\_output'
  * tests: Move json decoding to base test class
  * compute: Add missing microversion check for networks
  * compute: Fix '--network none/auto' handling
  * zuul: Remove nova-network tests
  * Add note about microversion 2.87 in server rescue help
  * compute: Add '--no-network', '--auto-network' flags
  * Improve \`server dump create\` helptext
  * Added "openstack image metadefs namespace list" command
  * Use the compute SDK in usage commands
  * quota: Deprecate "force" behavior for network quotas
  * quota: Fix issues with delete quota command
  * tests: Remove unnecessary nesting of volume resources
  * tests: Remove duplicate FakeImagev1Client
  * tests: Move fake clients to top of file
  * quota: Trivial style fixups
  * quota: Deprecate 'quota show --class', 'quota set --class'
    arguments
  * quota: Allow showing project-specific quotas
  * quota: Add 'quota show --usage' option
  * quota: Simplify logic used to list, show quotas
  * Fix server evacuate command
  * Speed up standard flavor list command
  * quota: Add support for detailed volume quotas
  * quota: Add 'quota delete' command
  * doc: Update cinder command mapping
  * Improve help text for network create --external
  * Switch to 2023.1 Python3 unit tests and generic template name
  * Update master for stable/zed
  * Fix wrong assertion methods
  * image: Add 'image task list' command
  * image: Add 'image task show' commands
  * Run swift in -tips job
  * Replace assertItemsEqual with assertCountEqual
  * Adding missing command mapping in docs
  * volume: Volume names are optional
  * compute: Add support for microversion 2.93
  * compute: Require image when rebuilding a volume-backed server
  * Add address-scope to NDP proxy tests
  * network: Add tenant project filter for RBAC list
  * Add router ndp proxy commands
  * Fix missing closing brackets in metavar
  * Remove invalid note from requirements files
  * Bump python-novaclient version
  * Microversion 2.91: Support specifying destination host to
    unshelve
  * remove unicode prefix from code
  * Fix documents for replaced configuration name
  * Migrate server\_groups to the new API
  * config: Also mask non-prefix config
  * Update the Nova CLI Mapping Guide
  * Add authorization\_ttl for identity providers
  * Add port ranges on floating ip portforwardings cli
  * docs: Add missing command mappings
  * Drop support for Python 3.6, 3.7
  * pre-commit: Allow unsafe YAML
  * Add support for CRUD operations for QoS minimum packet rate
    rule
  * image: Split image creation depending on service
  * image: Make better use of argparse
  * Fix: create image from volume command
  * image: Trivial style changes
  * Skip test\_quota\_network\_set\_with\_force func test
  * Don't show tenant\_id in network objects
  * Allow users to list all images
  * Migrate osc-tox-py3N-tips to Python 3.8
  * Add 'Host Status' to 'server list --long' with >= v2.16
  * volume: Correct output of 'volume attachment create'
  * Allow to filter multiple tags for image list
  * Stop testing lower-constraints
  * volume: Add 'block storage resource filter list' command
  * volume: Add 'block storage cluster \*' commands
  * Refactor network fakes to sdk properties PART 4
  * Stop using private \_is\_uuid\_like method
  * Add more filter option of columns for server list -c COLUMN
  * compute: Only retrieve necessary images
  * Add trustor and trustee filtering to trusts list
  * Allow "--force" flag in quota network commands
  * Refactor network fakes to sdk properties PART 3
  * compute: Add 'Security Groups' for 'server list'
  * Refactor network fakes to sdk properties PART 2
  * Refactor network fakes to sdk properties PART 1
  * Refactor "volume backup restore" command
  * compute: Move server migrations commands to their own file
  * compute: Allow retrieval of migration by UUID
  * volume: fix backup list of deleted volume
  * Add Python3 zed unit tests
  * Update master for stable/yoga
  * Fix metavars and typos in local\_ip
  * Add support for setting extra DHCP options on existing ports
  * volume list: don't fail when there's no compute service
  * Fix 'server event list|show' for deleted servers
  * docs: Document additional 'server migration' commands
  * Add support for 'remote-managed' vnic type
  * Don't fail on extlinks warnings for reno build
  * Support Neutron Local IP CRUD
  * Get rid of tenant\_id in the network commands
  * Switch compute service list, delete and set to sdk
  * Skip original\_name from flavor info
  * Fix volume set functional test
  * Add location to fake network objects
  * Hide location columns for network objects
  * compute: Pass through args to ssh
  * compute: Fix weird option definition for 'server ssh'
  * compute: Return information about fixed IP
  * Switch add fixed IP to SDK
  * tests: Improve logging for executed commands
  * Allow setting gateway when creating a router
  * Fix RemoveServerVolume
  * Add network update quota "limit\_check" parameter
  * Add --security-group to port list
  * compute: Show flavor in 'server list' with API >= 2.47
  * compute: Reorder building of columns for 'server list'
  * Switch server suspend and server resume to SDK
  * Switch server pause and server unpause to SDK
  * Switch openstack server remove port/network to using sdk
  * Allow unset port's host\_id
  * Switch command server remove volume to sdk
  * Add functional test for server add/remove volume
  * Temporarily drop aodhclient from doc build
  * Switch command server add volume to sdk
  * Add missing command mapping in nova
  * image: Sanity check the 'SetImage' command
  * tests: Update fake image client in tests
  * image: Remove FakeImage test helper
  * image: Remove dead test helper methods
  * Switch server image create to SDK
  * Switch openstack server add port/network to using sdk
  * compute: Return details of attached volumes
  * compute: Use correct command class for 'show migration'
  * compute: Don't warn if disk overcommit params unset
  * Switch server backup to sdk
  * Fix typos
  * Remove remnants of 'six'
  * Remove 'get\_osc\_show\_columns\_for\_sdk\_resource'
    duplicates
  * tox: Ignore virtualenvs for pep8 environment
  * compute: Fix filtering servers by tags
  * Update the Nova CLI docoder document
  * Update the Nova CLI decoder document
  * Remove non-working code after method return
  * Add --trusted-image-cert option for server create
  * Fix that the path of functional test
  * Add Python3 yoga unit tests
  * Update master for stable/xena
  * Replace assertItemsEqual with assertCountEqual
  * compute: Add support for microversion 2.89
  * compute: Add support for microversion 2.90
* Sun Jan 14 2024 cloud-devel@suse.de
- removed 0001-Skip-original_name-from-flavor-info.patch
- update to version 6.4.0
  - Add plugin doc page for cyborg
  - Allow server rebuild --wait for SHUTOFF servers
  - Allow multiple `--remove-tag` in `project set`
  - trivial: Make better use of argparse
  - Adding ``image import`` command
  - Silence warnings from openstacksdk
  - compute: 'server volume update' -> 'server volume set'
  - Migrate 'server event *' commands to SDK
  - Wait for volume being available to set bootable or readonly
  - Add image metadef resource type command 'list'
  - Adding ``image delete --store`` and ``image import info`` commands
  - Switch back to Launchpad
  - Adds command ``image metadef object create``
  - Adds command ``image metadef object list``
  - Fix pep issue in the network service provider
  - tests: Use consistent shortcut to fake compute client
  - tests: Use a new project for quota tests
  - Excluding test code from coverage reports
  - docs: Migrate volume commands to autoprogram-cliff
  - tests: Handle missing extensions in network tests
  - volume: Remove duplication from 'consistency group create' opts
  - Add missing documentation for state options for "image set"
  - tests: Use consistent shortcut to fake image client
  - Remove unnecessary 'self.methods'
  - docs: Add examples of common auth methods
  - tests: Remove unnecessary nesting of compute resources
  - Adding image stores info command
  - Use pre-commit for 'pep8' tox target, bump versions
  - Add a warning for resizing servers booted from volumes
  - Removed start, end time format. Before fix, openstack usage list command resulted 'str' object has no attribute 'isoformat' error.
  - compute: Migrate 'reboot server' to SDK
  - Drop default from ask_user_yesno question
  - volume: Support same_host, different_host hint as list
  - Add an updated tips job running on py310
  - tests: Centralise check for networking service
  - tests: Add network v2 FakeClientMixin
  - Remove use of oslo.utils
  - Blacken openstackclient.image
  - Fix tox v4 compatibility
  - Add support for default security group rule CRUDs
  - tests: Use fake SDK Migration object
  - Migrate backup commands to SDK
  - volume: Make better use of argparse
  - Neutron port hints
  - Update from storyboard to launchpad pt. 2
  - doc: Split image command documentation
  - Migrate 'volume summary' command to SDK
  - Switch list server volume to sdk
  - Switch server lock, unlock to sdk
  - tests: Remove FakeNetworkV2Client
  - Add "image metadef property delete" command
  - tests: Reorder compute fakes
  - Add "image metadef property list" command.
  - volume: Add 'volume qos set --no-property' option
  - Fix --security-group for port list
  - Migrate volume backend commands to SDK
  - Remove unused helpers for legacy novaclient
  - Migrate resource filter commands to SDK
  - image: Add support for cache commands
  - Blacken openstackclient.compute
  - Add --skip-resource option to project cleanup
  - tests: Use consistent shortcut to fake volume client
  - doc: Update nova command mapping
  - Migrate 'extension list' to SDK
  - Add "image metadef property create" command
  - Add pagination helpers
  - Fix "access rule" commands to only use ID
  - Switch server start, server stop to SDK
  - Add block storage manageable list commands
  - tests: Fix API extension check
  - Switch server volume update to sdk
  - Update 'host list' and 'host show' command to use sdk
  - Fix ReleaseNotes build
  - Show Network QoS rules one per line
  - Blacken openstackclient.identity
  - volume: Deprecate '--detailed' options
  - tox: Disable E501
  - Blacken openstack.common
  - Deprecate positional args for 'volume group create'
  - Adds command ``image metadef object show``
  - tests: Remove FakeImagev1Client, FakeImagev2Client
  - tox: Bump min_version to 4.3.0
  - tests: Use consistent shortcut to fake network client
  - Add "image metadef property show" command
  - pre-commit: Enable black
  - Propocol release versions properly
  - compute: Fix bug with start/stop server
  - trivial: Remove duplicate definitions
  - Add the flavor-id option to router create
  - Add auto-approve option to project cleanup
  - Add "image metadef property set" command
  - Dropping the use of 'addFixedIp' server action
  - Add is_incremental to ListVolumeBackup
  - Move network trunk commands from python-neutronclient
  - Migrate 'volume revert' command to SDK
  - Update the docker image to python3.11
  - Add volume summary command
  - Blacken openstackclient.volume
  - volume: Add aliases for common volume type props
  - Add volume revert command
  - Docs: Update glance command mapping
  - volume: Migrate 'volume group snapshot' commands to SDK
  - Ignore black changes
  - Blacken openstackclient.network
  - volume: Add 'volume type set --private/--public'
  - Update the underlying python containers to "3.10-bookworm"
  - compute: Generate SSH keypairs ourselves
  - Address pre-commit issues
  - tests: Use central SDK client fake
  - tests: Add image v1, v2 FakeClientMixin
  - Migrate 'availability zone list' to SDK
  - tests: Add compute v2 FakeClientMixin
  - Blacken everything else
  - tests: Use SDK objects where expected
  - Update branch regexes for tips jobs
  - Adds command ``image metadef object delete``
  - Add block storage log level {list, set} commands
  - tests: Add volume v1, v2, v3 FakeClientMixin
  - Switch server shelve, unshelve to SDK
  - Blacken openstackclient.object
  - zuul: Merge osc-functional-devstack-base into only child
  - Update master for stable/2023.2
  - Fix "server create"command with --boot-from-volume
  - tests: Explicitly specify port fields for output
  - compute: Switch server restore to SDK
  - Check the default role list before adding a new one
  - Switch server dump create to using sdk
  - Update master for stable/2023.1
  - "hypervisor list --matching" showed the wrong result
  - Add block storage cleanup command
  - tests: Check for DHCP agents first in DHCP test
  - Blacken openstackclient.api
  - Add options to create volume group from source
  - Remove project purge image commands
  - volume: Add alias for volume type AZs
  - volume: Allow filtering volume types by properties
* Sun Jun 19 2022 cloud-devel@suse.de
- added 0001-Skip-original_name-from-flavor-info.patch
* Tue Oct 26 2021 cloud-devel@suse.de
- removed 0001-Replace-assertItemsEqual-with-assertCountEqual.patch
- update to version 5.6.0
  - volume: Re-add accidentally deleted test
  - network: Add support for vnic-type vdpa
  - docs: Update cinderclient comparison doc
  - Replace assertItemsEqual with assertCountEqual
  - Show "Forced Down" compute service status with --long
  - Add support for Neutron's L3 conntrack helper resource
  - volume: Add missing 'volume list --offset' parameter
  - volume: Allow more versions
  - compute: Note that '--password' is deployment-specific
  - Make functional Neutron tests running fine on ML2/OVN environments
  - L3 conntrack helper: Use singular name consistently
  - Add pre-commit
  - Allow to send extra attributes in Neutron related commands
  - setup.cfg: Replace dashes with underscores
  - compute: Better help text for 'openstack server set --state'
  - docs: Update novaclient comparison doc
  - Hides prefix_length column in subnet show output
  - Implements hide image
  - volume: Add 'volume group snapshot *' commands
  - Remove unnecessary test
  - docs: Update neutronclient comparison doc
  - volume: Add 'volume attachment *' commands
  - volume: Add 'volume message *' commands
  - docs: Update glanceclient comparison doc
  - volume: Add missing 'volume backup *' options
  - cinder: Remove redundant command
  - compute: Update 'server resize --revert', '--confirm' help
  - Moving IRC network reference to OFTC
  - volume: Add 'volume group type *' commands
  - volume: Add 'volume group *' commands
  - openstack image create: honor protection/visibility flags
  - Correct REST API response fields for /os-migrations API
  - tests: Rename 'FakeType' -> 'FakeVolumeType'
  - [community goal] Update contributor documentation
  - volume: Add 'volume transfer request create --(no-)snapshots' option
  - Fix TestListMigrationV223 test class MIGRATION_COLUMNS
  - Update volume create documentation
  - compute: Fix typo
  - Correct the tox option for skipping sdist generation
  - Update master for stable/wallaby
  - hacking: Remove references to encoding
  - Add Python3 xena unit tests
  - network: Make 'network qos rule create --type' option required
  - Add support for token caching
  - Add check for cinderclient.v2 support
  - Set ML2/OVS backend explicitly in the devstack jobs
  - tests: Handle removal of block-storage v2 API
  - requirements: Drop os-testr
  - volume: Add more missing 'volume backup *' options
* Mon May 10 2021 cloud-devel@suse.de
- added 0001-Replace-assertItemsEqual-with-assertCountEqual.patch
* Sun May  2 2021 cloud-devel@suse.de
- update to version 5.5.0
  - Add source_ip_prefix and destination_ip_prefix to metering label rules
  - compute: Rename 'server migrate (confirm|revert)'
  - compute: Add missing options for 'keypair list'
  - Add an error message when server bind floating IP
  - Remove None valued network quota entries
  - trivial: Document removal of support for agents
  - Rename FakeServerMigration to FakeMigration
  - compute: Add missing 'server create' options
  - Add 'openstack server evacuate' command
  - compute: Remove deprecated 'server migrate --live' option
  - Fix lower-constraints job
  - compute: Fix 'server * -f yaml' output
  - compute: Add missing options for 'server set'
  - compute: Add missing options for 'server event list'
  - functional: Remove test for 'quota set --force'
  - Remove references to Python 2.7
  - compute: Add missing options for 'server image create'
  - Add 'address_group' type support to rbac commands
  - compute: Improve 'server create --block-device-mapping' option parsing
  - compute: Add functional tests for --block-device
  - Switch console url show operations to SDK
  - Always display direction for security group rules
  - Remove retired Karbor support
  - network: Add missing subnet unset --gateway <subnet-id>
  - compute: Add 'server show --topology' option
  - compute: Auto-configure shared/block live migration
  - Add device profile to ``port``
  - compute: Add 'server volume list' command
  - Add support for 'keypairs list --project' parameter
  - Add a few selectable fields to the "openstack server list" output
  - compute: Stop silently ignore --(no-)disk-overcommit
  - compute: Add missing options for 'server group list'
  - Add 'server unshelve --wait' option
  - zuul: Stop testing against Tempest
  - trivial: Rework 'CreateServer' function
  - trivial: Cleanup docs for 'server rebuild'
  - Add documentation about login with federation
  - compute: Fix 'usage * -f yaml' output
  - Add 'server shelve --offload', 'server shelve --wait' options
  - Add project field in image list subcommand
  - tests: Remove unused fake method
  - compute: Improve 'server migration list' options
  - Update master for stable/victoria
  - Validate 'server group create --policy' option
  - Update lower-constraints
  - Add reno for change Ic3c555226a220efd9b0f27edffccf6c4c95c2747
  - Add "fields" parameter to ListPort query
  - Switch 'openstack keypair' ops to use SDK
  - Cleanup of 'server migration list' command
  - compute: Add 'server * --all-projects' option
  - Add support '--progress' option for 'image create'
  - trivial: Use plural for appended parameters
  - Add --name to port list
  - compute: Add missing options for 'hypervisor list'
  - Remove usage of six
  - compute: Add missing options for 'server list'
  - Switch openstack console log show operation to use OpenStackSDK
  - compute: Improve 'server create --nic' option parsing
  - stop image downloads to memory
  - compute: Shuffle options for 'server create'
  - update lower-constraints.txt
  - Remove oslo.utils
  - compute: Fix 'server group * -f yaml' output
  - Add server migration list CLI
  - compute: Deprecate 'server create --file'
  - Add 'openstack server migration list --type' option
  - Compute: Add 'keypair create --type' parameter
  - Replace deprecated UPPER_CONSTRAINTS_FILE variable
  - tests: Remove 'agent' functional tests
  - Add name and enabled param in ListDomain parser
  - Compute: Add tag support for server add fixed ip
  - Resolve issues with 'server migration list'
  - Add Python3 wallaby unit tests
  - Add 'server migration force complete' command
  - Compute: Add user id support for keypair
  - Compute: Add tag support for server add volume
  - compute: Add --password option for openstack server create
  - Add support for 'keypairs list --user' parameter
  - Update the file paths mentioned in README.rst
  - Compute: Add tag support for server add network
  - project cleanup
  - Add option to filter instances by AZ
  - Switch compute aggregate functions to SDK
  - Switch compute flavors from novaclient/direct to SDK
  - compute: Add 'server migration show' command
  - compute: Add support for 'server boot --nic ...,tag=<tag>'
  - Restore behavior of image create with same name.
  - compute: Add 'server volume update' command
  - Add NODE and HOST parameters in "server create" help text
  - compute: Add support for loading BDMs from files
  - Fix formatting of the flavor properties
  - Make use of comparable 'FormattableColumn' subclasses
  - Remove references to setuptools
  - network: Address nits for I3c313fc9329837dde67815901528a34dca98ebcc
  - Add 'server migration abort' command
  - Compute: Add tag support for server add port
  - Change 'Volume' to 'Block Storage'
  - Compute: Add tags support for server
  - compute: Add 'server group create --rule' option
  - compute: Add missing options for 'server rebuild'
  - compute: Remove references to optional extensions
  - Remove the unused coding style modules
  - compute: Add '--force' option to 'server delete'
  - Fix: port attribute name propagate_uplink_status
  - Support remote-address-group in SG rules
  - Add id and enabled param in ListIdentityProvider parser
  - Support Neutron Address Group CRUD
  - Add 'openstack server create --use-config-drive'
  - Remove retired Searchlight support
  - compute: Fix 'hypervisor show -f yaml' output
  - Let autoprogram-cliff know who's running
  - image: Unset properties rather than setting to None
  - Allow to resize in-use volumes
  - compute: Remove 'file://' prefix from '--block-device'
  - trivial: Cleanup docs for 'server list'
  - compute: Add 'server create --block-device' option
  - Add 'flavor list --min-disk', '--min-ram' options
* Fri Oct  9 2020 cloud-devel@suse.de
- update to version 5.4.0
  - Switch to newer openstackdocstheme and reno versions
  - Add API check for server_groups.create
  - Cleanup Python 2.7 support
  - Remove congress
  - Add 'address_scope' type support to network rbac commands
  - Resolve PEP8
  - Add system role assignment tests for users and groups
  - Add '--force; parameter to 'openstack quota set'
  - Show words indicating booted from volume for server image
  - Fix reverted osc-lib interface change
  - Fix compatibility issue in 5.3
  - Support tagging Neutron ports on creation
  - Add NUMA affinity policy parameter to "port"
  - Add 'subnetpool' type support to rbac commands
  - Use unittest.mock instead of third party mock
  - Allow os quota list query to filter by project
  - Output correct json for security groups in 'openstack server show'
  - Add libc6-dev to bindep
  - Add description field to portforwarding NAT rules
  - switch to stevedore for entry points
  - Fix gate due to switch to focal
  - Revert "Format location columns in network commands"
  - Remove enabling of glance v1 API
  - Support for stateless security groups
  - Add cliff to libs-from-git for devstack functional tips
  - Fix uploading an signed image does not work if private signing key is encrypted
  - Expose flag for forcing use of import for images
  - Add a command to trigger entrypoint cache creation
  - Add resource option immutable
  - Be explicit about python version in image
  - Delete the testcases that arent needed anymore
  - Add py38 package metadata
  - Make volume backup record commands available in v3
  - bump py37 to py38 in tox.ini
  - Update master for stable/ussuri
  - Remove os-client-config references
  - identity: autogenerate docs
  - Fix --image-property option in 'create server'
  - Adding options to user cli
  - Allow openstack flavor set to update flavor description using name
  - Replace assertItemsEqual with assertCountEqual
  - Bypass user and group verification in RemoveRole
  - Cleanup: remove a useless reference to "object"
  - Add Python3 victoria unit tests
  - image: autogenerate docs
  - Remove translation sections from setup.cfg
  - Client should parse string to boolean for value 'is_domain'
  - Don't display Munch objects in the output
  - port: add --host to list command
  - Update developing.rst
  - Add API check for server_groups.list
  - Remove Babel from requirements
  - Correct image lookup during server rebuild
  - Remove install unnecessary packages
  - Revert "Disallow setting default on internal network"
  - Make container list --all work
  - Add OpenStack Client for Manila docs
  - Add command: router add/remove route --route
* Tue May 12 2020 cloud-devel@suse.de
- update to version 5.2.0
  - Add bindep file
  - Use 'KeyValueAppendAction' from osc-lib
  - Bump lower constraint of MarkupSafe
  - Replace six.iteritems() with .items()
  - Don't look up project by id if given id
  - Add storage policy option to create container command
  - Stop configuring install_command in tox and stop use pip.
  - Update http links in docs
  - Doc: launchpad => storyboard
  - Allow setting floating IP description
  - Deflate .htaccess
  - Fix network segment range "_get_ranges" function
  - Fix copypaste errors in access rule command
  - Remove redundant OpenStackShell.prepare_to_run_command
  - Remove plugin projects from test-requirements.txt
  - neutron: autogenerate docs
  - Incorrect title for service provider
  - Add plugin doc page for watcher
  - Show correct name for resource with quota set to zero
  - Disallow setting default on internal network
  - Fix openstack server list --deleted --marker option
  - Add support for app cred access rules
  - Fix plugin autodoc generation
  - Switch image to use SDK
  - Provide stderr in exception when check_parser fails
  - Microversion 2.79: Add delete_on_termination to volume-attach API
  - Complete switch from glanceclient to SDK for image service
  - Use autoprogram-cliff for remaining plugin docs
  - Bump tox minversion
  - Add unit tests and release note for dns_publish_fixed_ip
  - common: autogenerate docs
  - Update master for stable/train
  - Create Volume v3 functional tests
  - Change dockerhub password
  - Honor endpoint override from config for volume
  - Fix functional tests for py3
  - Stop testing python 2 in tox and zuul.
  - Raise hacking to more recent 2.0.0
  - Now we can add description for role creation in OSC
  - Build utility image for using osc
  - Replace port 35357 with 5000 for "auth_url"
  - Switch to using osc_lib.utils.tags
  - Split plugin docs per project
  - Fix router create/show if extraroute not supported
  - Add qos_network_policy_id to network port tests
  - Link to (some) plugin doc pages
  - Refactor AggregateTests
  - Remove trailing newline from dockerhub secret
  - Update a stale doc reference to use :neutron-doc:
  - Add dns_publish_fixed_ip attribute to subnets
  - Fix osc-lib interface change: catch osc-lib Forbidden
  - Use SDK to get compute API extensions
  - Add placement to known plugins
  - Update the content about Import Format
  - compute: autogenerate docs
  - versions: Fix 'versions show' help message
  - Add parent project filter for listing projects
  - Raise flake8-import-order version to latest
  - Add "fields" parameter to ListSecurityGroup query
  - openstack.cli: autogenerate docs
  - Add redirect testing
  - Stop silently ignoring invalid 'server create --hint' options
  - Produce complete content for plugin docs
  - Remove mention of meetings from docs
  - Update image building jobs
  - Add 'openstack server migrate (confirm|revert)' commands
  - Complete "Drop python2 support" goal
  - Fix faulthy state argument choice
* Tue Mar 24 2020 Dirk Mueller <dmueller@suse.com>
- add obsoletes
* Mon Mar 23 2020 Dirk Mueller <dmueller@suse.com>
- remove nonsensical update-alternatives, which leaves an empty file behind
* Thu Mar 12 2020 Dirk Mueller <dmueller@suse.com>
- switch to python 3.x only package
* Wed Oct  9 2019 cloud-devel@suse.de
- update to version 4.0.0
  - Batch up minor cleanups for release
  - Bump min osc-lib to 1.14.0
  - Fix RuntimeError when showing project which has extra properties
  - Fix BFV server list handling with --name-lookup-one-by-one
  - Fix typo: "to and endpoint"
  - Fix functional.base.TestCase.openstack() to optionally omit --os-auth-type
  - Use cliff formattable columns in image commands
  - Add server add/remove volume description for microversion 2.20
  - Document that server dump create requires 2.17
  - Remove code migrated to osc-lib long ago
  - Fix docs bug link to go to storyboard rather than launchpad
  - Mention compute service set --up|--down requires 2.11 or greater
  - Update master for stable/stein
  - Compute: Add description support for server
  - Remove deprecated volume commands and args
  - Volume backup functional test tweak
  - Use cliff formattable columns in network commands
  - Deprecate openstack server migrate --host option
  - Ignore case in security group rule --ethertype
  - Add host and hypervisor_hostname to create servers
  - Delete the LB object quotas set command in openstackclient
  - Rename review.openstack.org to review.opendev.org
  - Fix: incorrect check when no shared/private input
  - Remove deprecated image commands
  - Tweak network segment range fiunction tests
  - Default to Cinder v3 API
  - Fix <id> description for --block-device-mapping
  - Add floating IP Port Forwarding commands
  - Format aggregate command fields and de-race functional tests
  - docs: clarify compute service --service option
  - Fix bug in endpoint group deletion
  - Format location columns in network commands
  - Fix --limit option in image list sub-command
  - Add 'openstack server resize (confirm|revert)' commands
  - openstack port create support --extra-dhcp-option
  - Update release table for Train and 4.0.0
  - Update api-ref location
  - Add openstack server create --boot-from-volume option
  - Microversion 2.73: Support adding the reason behind a server lock
  - Aggregate functional test tweak
  - Bump lower constraint of python-zunclient
  - Follow-up: fix the invalid releasenote link
  - Change default security group protocol to 'any'
  - Followup opendev cleanup and test jobs
  - OpenDev Migration Patch
  - Fix link to new opendev repo
  - Remove token_endpoint auth type
  - Allow "server migrate" (not live) to take "--host" option
  - Add 'security_group' type support to network rbac commands
  - Bump hacking version
  - Fix: set invalid None project_id on range creation
  - Stop leaving temp files after unit test runs
  - Support type=image with --block-device-mapping option
  - Remove races in floating ip functional tests
  - Remove deprecated network options
  - Use cliff formattable columns in volume v1 commands
  - Fix compute service set handling for 2.53+
  - Add changes-before attribute to server list
  - Use cliff formattable columns in identity commands
  - Support IPv6 addresses better
  - Fix service discovery in functional tests
  - Serialize more aggregate functional tests
  - Update the constraints url
  - Add CLI argument tests before making changes
  - More aggregate functional race chasing
  - Dropping the py35 testing
  - Remove deprecated compute commands
  - Add Python 3 Train unit tests
  - Blacklist Bandit 1.6.0 due to directory exclusion bug
  - Remove deprecated identity commands and args
  - Microversion 2.77: Support Specifying AZ to unshelve
  - Use cliff formattable columns in object storage commands
  - Document 2.53 behavior for compute service list/delete
  - document the --timing option
  - Add server event command documentation for compute API 2.21
  - Update sphinx requirement.
  - Fix module paths for volumev3 volume backup commands
  - Make configuration show not require auth
  - Before writing object data to stdout, re-open it in binary mode
  - Add doc and relnote for review 639652
  - Clean up app initialization and config
  - Use cliff formattable columns in volume v2 commands
* Mon Apr  8 2019 cloud-devel@suse.de
- update to version 3.18.0
  - Fix missing trailing spaces in network help messages
  - Add volume backend capability show command
  - Add metavar for name parameter in subnet create
  - Modify the help message for 'registered limit set'
  - image/v2: support multiple property filters
  - Add note about version 2.5 when listing servers using --ip6
  - Add dns-domain support to Network object
  - Fix broken gate jobs
  - Fix 'project purge' deleting wrong project's servers and volumes
  - Support enable/disable uplink status propagation
  - Allow endpoint filtering on both project and project-domain
  - Add --key-name and --key-unset option for server rebuild API.
  - Remove invalid 'unlock-volume' migration arg
  - Default --nic to 'auto' if creating a server with >= 2.37
  - Add monascaclient to `not plugins` list
  - import zuul job settings from project-config
  - Add DNS support to floating IP commands
  - More state handling in volume transfer requests functional tests
  - Updated the take_actions for unified limits
  - More volume functional test fixes
  - Use devstack functional base job
  - Add --property option to 'server rebuild' command
  - This fix removes an erroneous underscore found within the function named
  - Partially Revert "Add command to unset information from Subnet-pools"
  - API microversion 2.69: Handles Down Cells
  - Don't display router's is_ha and is_distributed attributes always
  - trivial: modify spelling error of project
  - Disabling c-backup service for osc-functional-devstack-tips job
  - Detailed help message for QoS max-burst-kbps value
  - Update release note version reference table
  - Update reno for stable/rocky
  - Update the Neutron CLI decoder document
  - Make use of keystoneauth service-type filtering for versions
  - add python 3.6 unit test job
  - Deprecate volume create --project and --user options
  - trivial: remove commented-out code
  - Typo fix
  - Change openstack-dev to openstack-discuss
  - Remove str() when setting network objects names
  - Add Python 3.6 classifier to setup.cfg
  - Replace assertEqual(True/False, expr) with assertTrue/assertFalse
  - Remove testr.conf as it's been replaced by stestr
  - Add py36 env
  - add lib-forward-testing-python3 test job
  - Fix inconsistency (nit)
  - osc-included image signing (using openstacksdk)
  - Update the URL in doc
  - Add possibility to filter images using member_status
  - Handle multiple ports in AddFloatingIP
  - Mention 2.51 in help for openstack server event show
  - Add osc repo to the base job definition
  - Add --name-lookup-one-by-one option to server list
  - switch documentation job to new PTI
  - Add floating IP filter to floating IP list command
  - Address issues from volume backend commands
  - Paginate over usage list to return all usages
  - fix tox python3 overrides
  - Fix i18n issue
  - Add network segment range command object
  - Improve document 'openstack complete'
  - Add volume backup import/export commands
  - Supports router gateway IP QoS
  - Add volume backend pool list command
  - fix multiple server delete produce multiple new lines
  - Fix some spaces in help messages
  - Fix: Restore output 'VolumeBackupsRestore' object is not iterable
  - Fix help message for subnetpool default-quota value
  - Use os-cloud instead of OS env vars for functional tests
  - Fix help message of image add project
  - Handle not having cinderclient.v1 available
  - Mention compute API 2.50 in openstack quota show --class
  - Add support for get details of Quota
  - Add --attached / --detached parameter to volume set
  - add python 3.7 unit test job
  - Remove python-ceilometerclient
  - Use templates for cover and lower-constraints
  - Add project param in LimitList parser
* Wed Dec  5 2018 cloud-devel@suse.de
- update to version 3.16.2
  - Fix 'project purge' deleting wrong project's servers and volumes
  - Allow endpoint filtering on both project and project-domain
  - Handle multiple ports in AddFloatingIP
  - Default --nic to 'auto' if creating a server with >= 2.37
* Wed Nov 28 2018 cloud-devel@suse.de
- update to version 3.16.1
  - Update UPPER_CONSTRAINTS_FILE for stable/rocky
  - Update .gitreview for stable/rocky
  - import zuul job settings from project-config
  - Fix broken gate jobs
* Mon Sep  3 2018 cloud-devel@suse.de
- update to version 3.16.0
  - Implement support for registered limits
  - Prevent "server migrate --wait" from hanging
  - Pass volume snapshot size to volume create
  - Update reno for stable/queens
  - neutron: add --mtu for create/set network
  - Make osc-functional-devstack-tips actually use tips
  - Update role document to include system parameter
  - Imported Translations from Zanata
  - Format port_details field of Floating IP
  - Rename python-openstacksdk to openstacksdk
  - Fix limits show command without Nova and Cinder
  - Clean up W503 and E402 pep8 errors
  - Correct application credential usage doc
  - Use Server.to_dict() rather than Server._info
  - Support filtering port with IP address substring
  - Retry floating IP tests
  - Remove deprecated ip floating commands
  - Fix volume type functional tests
  - Display private flavors in server list
  - Fix server show for microversion 2.47
  - compute: host: expand kwargs in host_set() call
  - Zuul: Remove project name
  - Add release note link in README
  - Fix docs from I0dc80bee3ba6ff4ec8cc3fc113b6de7807e0bf2a
  - Add support for endpoint group commands
  - Fix crashing "console log show"
  - Add project tags functionality
  - Fix additional output encoding issues
  - Add ability to filter image list by tag
  - Replace pbr autodoc with sphinxcontrib-apidoc
  - Add help for nova interface-list to decoder
  - Slow down and retry aggregate create/delete to lessen race
  - Add --image-property parameter in 'server create'
  - Change bug url to a correct one
  - Add support for "--dns-domain" argument
  - Add cliff project link
  - Update command test for volume.v3
  - Fix the `role implies list` command.
  - Add command to show all service versions
  - compute: limit the service's force down command above 2.10
  - Update help text for encryption provider
  - Update links in README
  - Trivial: Update pypi url to new url
  - Add system role functionality
  - Remove duplicated network attributes
  - Fix tox -e venv -- reno new <slug>
  - Implement support for project limits
  - Add bgp commands to neutron decoder
  - Add support to list image members
  - Release note cleanup for 3.16.0 release
  - Allow setting network-segment on subnet update
  - Use find_ip from openstacksdk
  - Network: Add tag support for security group
  - Skip calls to glance and nova when got no servers
  - Network: Add tag support for floating ip
  - Fix typo in 'floating ip associate' command and doc
  - Fix functional job failed
  - Cleanup error messages on failure
  - Don't sent disk_over_commit if nova api > 2.24
  - Add CRUD support for application credentials
  - Optimize _prep_server_detail to avoid redundant find_resource
  - Fix error with image show when image name is None
  - Make max_burst_kbps option as optional for bw limit QoS rule
  - Fix subnet host_routes error
  - add lower-constraints job
  - Re-implement novaclient bits removed in 10.0
  - Adding api_version to FakeApp
  - Make functional-tips job voting
  - Do not require port argument when updating floating IP
  - Support --community in openstack image list
  - Fix lower-constraints.txt
  - Compute: Add description support for flavor
  - Updated from global requirements
  - Make Profile fallback go bye-bye
  - Fix urls in README.rst
* Fri Feb 23 2018 tbechtold@suse.com
- Switch to stable/queens spec template
* Mon Feb 12 2018 cloud-devel@suse.de
- update to version 3.14.0 (bsc#1078607)
  - Fix use of new openstacksdk connection
  - Fix func tests: Ensure to pass OS_CLOUD envvar
  - Use Zuul v3 fetch-subunit-output
  - Switch to use stestr directly
  - Fix indentation in authentication.rst
  - Allow ports filtering with device_id
  - Rework Network client config for new SDK Connection
  - Partially Revert "Update new documentation PTI jobs"
  - Update new documentation PTI jobs
  - Check that Glance returns image data before processing it
  - Corrected spelling mistake
  - Allow port list to shown undefined attributes
  - Add floating IP qos_policy actions
  - Replace assert with condition
  - flavor: clarify --swap description
  - Updated from global requirements
* Thu Jan 18 2018 tbechtold@suse.com
- Convert to singlespec
* Mon Jan 15 2018 cloud-devel@suse.de
- update to version 3.13.0
  - Add RemoveNetwork command to server
  - Accept 0 for --min-disk and --min-ram
  - network functest: Remove condition for segment test
  - Switch to $USER in post_test_hooks
  - Remove a bunch of things we promised to remove in 2H 2017
  - Attempt to de-race qos policy
  - Make py27 and py35 versions and template of unit-tips jobs
  - Make osc-tox-unit-tips work on other repos
  - Support creating unaddress neutron port
  - Imported Translations from Zanata
  - Remove hard-coded policy choices for creating a server group
  - Native DevStack jobs
  - Update image cli doc and fix some typos
  - Use instance variables for subnet tests
  - Prepare for os-clinet-config to go away
  - Show detailed message of neutron exception
  - Neutron agent delete: remove the wrong argument
  - Implied Roles
  - Unroll the network qos policy functional tests
  - Add wrapper around ostestr
  - Be robust on import plugin module
  - Replace %%r with %%s on printing string variable
  - Add server rescue unit tests
  - Send 'changes-since' instead of 'changes_since' query parameter
  - openstack subnet create fails when tags is None
  - Update the documentation link for doc migration
  - Fix output for subnet show
  - flake8-import-order: Ensure to place project imports last
  - Fix 'project purge' deletes ALL images problem
  - Updates for stestr
  - Fix credentials in create, update and list.
  - Added AddNetwork command to server
  - Zuul: add file extension to playbook path
  - Use flake8-import-order plugin
  - Add support for endpoing filter commands
  - Replace guildelines with guidelines
  - Update release/stable branch table in docs
  - auto-generate docs for v3 identity resources
  - Release note cleanup
  - Skip object-store functional tests when Swift is not available
  - Allow PD as Subnetpool during Subnet creations
  - Convert network segment functional tests to JSON
  - Remove -U from pip install
  - Fix "openstack image unset" command's help message typo
  - Skip Volume v1 functional tests if v1 not present
  - Add "volume service list --host" functional test case
  - Move base functional test job in-repo
  - Convert network security group functional tests to JSON
  - Convert network qos functional tests to JSON
  - Support icmp-type and icmp-code to be set as zero
  - Convert 'server' commands to use autoprogram
  - Add python-zunclient plugin
  - Fix SDK Connection creation alternative to Profile
  - Avoid default mutable values in arguments
  - Add cliff and keystoneauth to tips jobs
  - Allow creating security rules without protocol
  - Correct import of keystoneauth1 session
  - Add .htaccess for docs migration
  - Attempt to work around chronically failing server issues with aggregates and qos
  - Move more jobs in-repo
  - Display Network QoS rule type details
  - Set correct designate endpoint in docs
  - Avoid tox_install.sh for constraints support
  - Updated from global requirements
  - Optimize getting endpoint list
  - Zuul job updates
  - Convert remaining network functional tests to JSON
  - Update reno for stable/pike
  - Use *_as_ids instead *_as_list
  - Network: Add interfaces info in router show
  - Remove setting of version/release from releasenotes
  - Fix subunit collection in functional tests with ostestr>=1.0.0
  - Add new commands for karbor osc plugin
  - Revert "Disable karborclient until a fixed version is released"
  - Network: Add supports rbac target-all-projects
  - Fix file mode on network-topology.rst
  - Rehome test units lib
  - Useless line of code in shell.py
  - Add python-rsdclient into plugin list
  - Add functional test cases for "volume qos associate/disassociate"
  - auto-generate object docs
  - Add logic to handle old and new sdk constructor
  - Add missing parameters on openstack server rescue
* Mon Aug  7 2017 cloud-devel@suse.de
- update to version 3.12.0
  - Don't show hint about vlan transparent in network set
  - Explicitly set 'builders' option
  - Minor followup to network agent docs
  - Add python-octaviaclient plugin
  - Structure FindFloatingIP() to work without ip_cache
  - Fix 'domain' filter not work well in some commands
  - Start using 'cliff.sphinxext'
  - JSON-ify image functional tests
  - Clean up password prompt work-arounds
  - Add support for virtio-forwarder VNIC type
  - Make test_server.py more elegant and simple
  - volume functest: ensure snapshots deleted when volume delete
  - Replace "Display Name" by "Name" in volume list
  - Allow objects to be streamed to stdout
  - wrong values in openstack quota show command
  - Fix man page build
  - Trivial Fix
  - Split network tests
  - Fix network list functional test
  - Low-level Compute v2 API: security group
  - Adds missing flavor information in the server list long command
  - Add default-quota to subnet pool commands
  - Use identity auth v3 the README examples
  - Updated from global requirements
  - Use Sphinx 1.5 warning-is-error
  - Fix Mapping Guide Error
  - Enable some off-by-default checks
  - Simplify logic around option lists in port set
  - Add the other commands for karbor osc plugin
  - Fix Trivial Changes in [1]
  - Create server with security group ID and name
  - Introduce neutron flavor associate, disassociate to OSC
  - Added 'openstack image set --visibility'
  - Do not always init compute_client when doint port list
  - Network L3 Router Commands for OSC
  - Add --network and --port to server create
  - Low-level Compute v2 API: network
  - Fix server create with nova-net
  - Update to tox.ini
  - Fix quota functional tests for nova-net
  - Low-level Compute v2 API: security group rules
  - Remove inaccurate mapping of 'host-meta' in csv
  - Ignore more exceptions in quota list
  - Introduce Neutron DHCP agent commands to OSC
  - Make MAC address of port updatable
  - Funcional tests: quota list
  - Enable to add/remove port to/from a server
  - Skip floating ip attach functional test on nova-net
  - Use openstackdocstheme in release note
  - Rework floating ip functional tests
  - Narrow expected responses for CheckUserInGroup
  - Low-level Compute v2 API: floating ip pool
  - Fix block-device-mapping when volume_size is empty
  - Remove ipdb installation in tox debug section
  - Nova net functional tests round 1
  - Nova net functional tests round 2
  - Nova net functional tests round 3
  - Fix unit test failures related to new os-client-config and osc-lib
  - Add help commands withouth auth in functional
  - Fix volume qos spec list
  - Fix NoneType error for volume snapshot create command
  - When creating a trust, send role_ids instead or role_names
  - Add domain parameter to Identity Provider
  - Add direction field to QoS bandwidth limit.
  - Correct flavor associate/disassociate commands in Mapping Guide
  - Disable karborclient until a fixed version is released
  - Functional tests: Identity v2 and DevStack
  - Allow override of distributed router flag
  - Release notes cleanup for 3.10.0 release
  - Change noauth strategy for plugin loading
  - Add project purge command to osc
  - Release note cleanup for 3.12.0
  - Add missing barbican commands
  - Add extra filtering options to qos policy list
  - Low-level Compute v2 API: floating ip
  - Clean up the changes of os.environ in functional tests
  - Add new parameter "is_default" to Network QoS policy.
  - Trivial fix typos
  - image-list should support filters 'name','status'
  - Doc: Fix link in network flavors
  - doc: Remove local fork of apidoc
  - Enable to create legacy router
  - Add optional parameter "user_id" and "type" to list credentials
  - Remove log translations
  - Nova-net functional tests: aggregates
  - Support to add/remove multi users for "group add/remove user"
  - Enable to specify which vm fixed-ip to publish
  - update the docs URLs in the readme
  - Split security group tests
  - Convert volume functional tests into JSON format
  - OSC Extension Show
  - Enable to specify which fixed-ip to add to a vm.
  - Use _get_token_resource in role assignment list
  - Fix volume transfers request commands
  - OSC Network Flavor Profile
  - reorganize existing documentation according to the new standard layout
  - docs: Don't include ChangeLog
  - move auto-generated api docs into contributor tree
  - Make block-device-mapping more stable and clear
  - Fix dynamic names in network functional tests
  - Fix Nova-net netowrk commands
  - network tag UT: avoid using mix-in test class
  - Help/docs cleanups: marker, limit, ip-address metavars
  - Add support for Karbor Plugin
  - Improve no-auth path
  - Network tag support
  - doc: Correct Sphinx warnings
  - Convert image functional tests into JSON format
  - "floating ip set/unset port" for OSC
  - Fix column names for server list --no-name-lookup
  - Split floating IP tests
  - Add "qos-policy" option to "port create" & "port set"
  - Functional test for subnet_pool
  - Correct the "extra spec" command openstack
  - Add server list -n and --no-name-lookup arguments
  - Non-Admin can't list own projects
  - Refactor Extension show and list command
  - Now OSC server create check keys in --nic
  - Show neutron tags in OSC network show
  - Add document about renaming OS_ENDPOINT_TYPE to OS_INTERFACE
  - Add 'data_plane_status' option to Port classes
  - switch to openstackdocstheme
* Mon Feb 13 2017 cloud-devel@suse.de
- update to version 3.8.1:
  - Tivial:update the description format in volume_snapshot.py
  - Should support 'auto' and 'none' as network parameter when boot instances
  - Fix all missing "os to openstack" transformation
  - unskip port test
  - Fix typo in release notes
  - Fix floating IP delete and show by IP
  - change os in command example to openstack(3)
  - Fix network create --project
  - Add one test for "backup set" command
  - Update the description format
  - Fix quota show --default command
  - fix functional tests for network agents
  - Avoid duplicated project_id when show network resources
  - Fix quota set command error for SDK > 0.9.10
  - Add options to allow filtering on agent list
  - Error handling for delete commands in identity
  - Update earliest-version number format in release notes
  - Make 'object save' fast again
  - Add --default option to "volume type list"
  - change os in command example to openstack(2)
  - Add --project and --project-domain option to "volume snapshot list"
  - Add relnotes for the two recent bug fixes
  - Update devref about "--no-property"
  - Functional tests - flavor
  - Release 3.7.0 cleanup
  - Adjust the code sequence in consistency_group.py
  - Fixes image api URL endpoint for certain scenario
  - Fix the missing os in command in example
  - Fix Octavia gate breakage caused by _get_columns()
  - Fix flavor create help re swap size units
  - OSC Network Meter
  - Updated from global requirements
  - Correct missspellings of secret
  - update server migrate '--wait' description
  - SDK Refactor: Prepare router commands
  - Add support for clearing router gateway
  - Add doc for Searchlight client
  - Modified API calls in os usage
  - change assert_show_fields to not fail on new fields
  - SDK Refactor: Prepare port commands
  - [TrivialFix] Fix typo error
  - Add unit tests for usage commands in compute v2
  - Fix network service provider functional test
  - Add server test for image and flavor lookups
  - Beef up floating IP functional tests
  - Functional tests - port
  - Fix filter error in os volume list
  - Add support for setting router gateway
  - Add plugin adoption for trove
  - Update functional test for aggregate.
  - Fix Network QoS rule CLI attrs parsing
  - Introduce overwrite functionality in ``osc router set``
  - Fix port command for SDK >0.9.10
  - Remove the fixed set of choices for network_type
  - Error in the return of command server show, create
  - Fix subnet creating failure in functional test
  - Fix Identity functional tests to not require OS_AUTH_URL
  - Beef up address scope functional tests
  - Add options to "server list" command
  - Remove unneeded methods from OS_Config class
  - Add "consistency group show" command
  - Fix quota show output
  - Cleanup for 3.8.0 release
  - Fix creating a private flavor with ID auto
  - Test-requirements.txt: Bump Hacking to 0.12
  - Use git+file urls instead of directories
  - Handle 403 error on creating trust
  - Error in the return of command 'volume qos create'
  - Add meter rule to OSC
  - Add "dns-name" option to "os port create" and "os port set"
  - Add 'allowed address pairs' option to 'port create/set/unset'
  - Add support for QoS rule type commands
  - Add two consistency group commands
  - Add server_boot_from_volume() test
  - add domain id to expected IdP fields, unskip tests
  - SDK refactor: Prepare security group commands
  - Add "consistency group set" command
  - Support "--no-property" option in volume snapshot set
  - functional test for volume
  - Fix "ip availability show" command
  - change os in command example to openstack
  - Add extra filtering options to floating ip list
  - Add support for Network QoS rule commands
  - Trivial: update volume-qos.rst
  - Remove auth_with_unscoped_saml decorator
  - SDK refactor: Prepare network commands
  - 3.5.0 release note cleanup
  - Add support for Glance 'update image members' feature
  - unskip network qos rule type functional test
  - Fix a spelling error
  - Add unit test for multi volume types delete
  - Fix image member unit tests occasional failures
  - Switch server create to block_device_mapping_v2
  - Add ploop to supported disk formats
  - Adds domain specification for SetUser
  - update plugins documentation
  - add support for running tests with master dependencies
  - Add ":option:` `" in the help message
  - Add "consistency group delete" command
  - Add "consistency-group-snapshot" option to consistency group create
  - Add '--force' option to 'volume snapshot delete' command
  - Update container format choices
  - Add some options to "volume create" command
  - Functional test for volume snapshot
  - Fix OSC networking commands help errors
  - Use image client for images instead of compute
  - To support '--project' and '--project-domain' options
  - Fix address scope list --share
  - Add '--type'and other options to network rbac list
  - WIP: Skip broken functional tests...
  - Fix security group rule list for NEtwork v2
  - skip tests related to SDK 0912 and keystone IdP change
  - Add "--remote-source" option to "volume snapshot create" command
  - Fix network functional tests for sdk 0.9.12
  - Install from /opt/stack/new instead of git.o.o
  - SDK refactor: Prepare network agent commands
  - Fix sphinx errors
  - Add filtering options to the address scope list command
  - Fix functional test for creating subnet
  - Revert "WIP: Skip broken functional tests..."
  - SDK Refactor: Prepare ip availability commands
  - Functional tests debug support
  - Revert "Remove marker and loop from "image list" command"
  - Beef up network functional tests
  - Fix 'mapping set' return value
* Thu Jan 12 2017 dmueller@suse.com
- update to 3.2.1:
  * Add relnotes for backports for 3.2.1 release
  * Defer auth prompting until it is actually needed
  * Use project_domain_id only in password auth
  * Use stable/newton branch in tox_install.sh and tox.ini
  * Mask passwords in debug logs for auth_config_hook
  * Updated from global requirements
  * Update .gitreview for stable/newton
* Fri Sep  9 2016 tbechtold@suse.com
- Remove some BuildRequires only needed for documentation.
* Fri Sep  2 2016 tbechtold@suse.com
  update to version 3.2.0
  * [docs] fix incorrect rst markups
  * Cleanup after install
  * Provide fallback prompt function for current osc-lib
  * Clean imports in code
  * Fix six typos
  * Fix auth prompt brokenness
  * Updated from global requirements
* Thu Sep  1 2016 tbechtold@suse.com
  update to version 3.1.0
  * Add create_one_image_member() in FakeImage class and update test
  * Fix error for find_service() in identity
  * fix one spelling mistake and two help messages
  * Add "--project" option to "volume type create" command
  * Remove discover from test-requirements
  * Standardize import format
  * Update Fakes.py and unit tests for commands in identity V2.0
  * Add support of setting volume's state
  * Remove execute permission on a few files
  * Add a document for required options
  * Add python-neutronclient to OSC plugins
  * Add notes, modify notes in fakes docstring
  * Rework clientmanager
  * Fix doc issue for "compute agent list" command
  * Pass security group id to novaclient
  * Remove useless dest of option in "snapshot create" command
  * Add port security option to network commands
  * skip image tag tests
  * Add "--marker" and "--limit" options to "snapshot list"
  * Add --ip-version filtering option to subnet.rst
  * Add support for domain specific roles
  * Add command to unset information from ports
  * Add Python3.5 to setup.cfg tox.ini
  * Implement network agents functionality
  * Updated from global requirements
  * Pass security group id to novaclient while adding security
  * Allow format selection in get_opts
  * Add '--dhcp' and '--no-dhcp' options to os subnet list cmd
  * Transfer "ip fixed add/remove" to "server add/remove fixed ip"
  * Integ test cleanup
  * arguments are not locale decoded into Unicode
  * Support bulk deletion for delete commands in identityv3
  * Fix OSC identity v3 functional tests
  * "server list": "Image Name", "Image ID" columns
  * skip failing tests due to bug 1599333 is fixed
  * Add command to unset information from Subnet-pools
  * remove unused LOG
  * Add "--snapshot" option to "backup create" command in volumev2
  * OS_DEFAULT_DOMAIN must be an ID
  * Follow upper constraints for all tox targets
  * Implement "network rbac set" command
  * Modify some help and error messages in ec2creds identityv2
  * Restore default auth-type for token/endpoint
  * update requirements and test requirements
  * Fix errors in volume set/unset image properties unit tests
  * Support bulk deletion for delete commands in computev2
  * Fix post and periodic jobs
  * Support multi REST API calls error handling for "volume set" command
  * Add support for deleting volumes with associated snapshots
  * Implement rbac list and show command
  * Support error handling for delete commands in volumev2
  * Add unit tests for group commands in identity v3
  * Add missing "Volume version 2 only" message in backup.rst
  * Remove FakeService.get_services
  * update plugin documentation
  * Remove useless dest of option in volume v1&v2
  * Use identity fake classes instead of old unit tests data
  * Unskip tests caused by bug 1599333
  * Fix up last-minute imports to use osc-lib
  * Implement network rbac create and delete commands
  * osc-lib: shell
  * Rename backup commands in volume v1 and v2
  * Added a note on how to test changes
  * Make set/unset command in volume pass normally when nothing specified
  * image list: Add Checksum column
  * Update the description of project in releasenotes.
  * Temp work around for missing select_auth_plugin()
  * Add '--force' option to 'backup delete' command in volumev2
  * Modify some unusual help messages in computev2
  * Exchange the check order for the dhcp and no-dhcp
  * modify notes in the FakeHypervisorStats docstring
  * Add command to unset information from Routers
  * Remove an outdated directory in tox.ini
  * Gate-unbreaking combo review
  * Change to plural form of object in multi delete error message in networkv2
  * Make set/unset commands pass normally when nothing specified in identityv3
  * Add unit tests for "host list" and "host show" commands
  * Update doc for credential in indentityv3
  * Correct reraising of exception
  * Add "--force" option to "backup create" command in volumev2
  * Change "ID only" to "name or ID" for backup commands
  * Add "--property" option to "snapshot create" command in volumev2
  * Transfer "ip floating add/remove" to "server add/remove
  * Work around a version clash issue with os-client-config
  * Set identity v3 client in networkv2 fake
  * Add "--property" option to "flavor create" command
  * Add "--force" option to "volume qos delete" command
  * fix a few spelling mistakes
  * Unit test of credential in identityv3
  * Refactor identity v3 unit tests with fake class
  * Allow setting quotas for server groups and server group members
  * Remove temporary code in ClientManager
  * Unskip the tests affected by warlock 1.3.0
  * Modify compute agent set command
  * Transfer "ip floating pool list" to "floating ip pool list"
  * Transfer "ip floating CRUD" to "floating ip CRUD"
  * Add missing '(name only)' message for keypair in computev2
  * Modify few words and change output format for command "ip floating list"
  * Clarification of option name rules
  * Use assertEqual() instead of assertDictEqual()
  * Add shell integration test
  * Show project access for volume type
  * Add assignment list to v2 identity and deprecate alternate listing
  * Refactor unit tests for project and domain with fake classes in identityv3
  * Add command to unset information from Subnets
  * osc-lib: api.auth
  * Deduplicate get_opts methods
  * Document network trunk  commands
  * fix some spelling mistakes in doc/
  * Fix several flake8 code style issues in compute tests.
  * document locale and language support tips
  * Add network-topolopy support
  * Implement "network agent set" command
  * Use FakeProject and FakeDomain classes in unit tests of networkv2
  * Add options to "volume type list" command
  * Add "--incremental" option to "backup create" command in volume v2
  * Show "target_project_id" attribute properly for network rbac object
  * Add Support for showing flavor access list
  * Make the doc build reproducible
  * Support to get server rdp/serial/mks type console url
  * Change the wrong import order
* Wed Aug 31 2016 tbechtold@suse.com
  update to version 2.6.0
  * Add newline to strings in stdout/stderr.write()
  * Implement "address scope create" command
  * Fix server group document issue
  * Add functional tests for IP availability
  * Modify lowercase to uppercase
  * Add functional tests for server group in ComputeV2
  * Imported Translations from Zanata
  * Fix output and error log in server.py
  * Rename --profile to --os-profile
  * Fixes BadRequest when no --pool-prefix given
  * Fix functional test for floatingip add/remove in ComputeV2
  * Support deleting multi address scopes in networkv2
  * i18n support for leftover exception messages in volume
  * Add new share and default parms to subnet pool cmds
  * Documentation updates
  * Added "name" parameter to the help message.
  * Trivial: Remove duplicated line in man page
  * Map server power state num to meanful string
  * fix keypair help msg
  * Support multiple argument for compute agent delete command
  * Add unit tests for "server show" command
  * Refactor TestImageList with FakeImage class
  * Fixed subnet command host route output
  * Release note cleanups for 2.6.0
  * Fix image tests to use warlock resources
  * Add FakeQos class and update unit test for qos_specs in VolumeV2
  * Fix i18n support for help and log.warning in image
  * Refactor service unit tests
  * add unit test for compute agent command
  * Fix functional test failures
  * Added --no-route to the router set command
  * Add functional tests for commands of floating ip
  * Updated from global requirements
  * Changed the nomenclature of credentials command
  * Add support for volume transfer request list
  * keystone: fix catalog output when region is unset
  * Add ip version filter to subnet list
  * Release notes cleanup
  * bump timeout to prevent gate failures
  * Refactor TestAddProjectToImage with FakeImage class
  * Implement "address scope set" command
  * Add support for setting flavor-access
  * Use find_resource() instead of get() in _prep_server_detail()
  * Fix i18n support in cinder
  * Modify the style of translated messages
  * Add "server group list" command
  * Add network segment command object
  * Implement "address scope list" command
  * Update tests for server
  * Add network availability for osc
  * Add "server group show" command
  * Add FakeType class and update volumetype test in VolumeV2
  * Implement "address scope show" command
  * Add "server group create" command
  * remove #noqa from i18n imports
  * Do not require an scope when setting a password
  * Add a unit test for "flavor create" command
  * Add support for removing flavor-access
  * Search by user defined ID for identity providers
  * Add FakeBackup class and updata backup unittest in volumeV2
  * Add some functional tests for commands in VolumeV2
  * Fix error in flavor set/unset command
  * Refactor TestVolumeShow with FakeVolume
  * Support error handling for "port delete" command
  * Update v2 endpoint show help
  * Remove unnecessary type conversions in network unit tests
  * Add commands of clustering service to doc
  * Check port name in set port tests
  * Pep8 environment to run on delta code only
  * Make "flavor show" command to show a private flavor properly
  * Support for volume service list
  * add a bandit environment to tox
  * [compute] Add server backup function
  * Support quota show for current project
  * fix endpoint show help
  * Fix functest "test_server_metadata()" in test_sever.py
  * Add describe of overwrite options behavior into devref
  * Fix network router type display
  * Fix i18n support for help and error messages in compute
  * Search by user defined ID for service providers
  * Fix errors for "volume type unset" command
  * Replace tempest-lib with tempest.lib
  * Ignore domain related config when using with keystone v2
  * Fix help message for "server group delete" command
  * Fix wrong test in flavor unit tests
  * Make set/unset commands in volume return normally when nothing specified
  * Add FakeSnapshot class and update snapshot test in VolumeV2
  * Doc: Add network resource descriptions
  * Spec to Implement IP Availability
  * modify server group
  * Added CONTRIBUTING.rst file
  * Add VLAN Transparent option to ``osc network``
  * Fix unit test for volume commands in volumev2
  * Trivial: Fix i18n support in network/common.py
  * Add "server group delete" command
  * Fix mutable default arguments in tests
  * Trivial: Remove unuseful comments for assertRaise() checking
  * Refactor SetService --enable/disable option
  * Trivial: Fix an omited i18n issue
  * Refactor TestVolumeList with FakeVolume
  * Implement "address scope delete" command
  * Support to set server state
  * Fix i18n support problems in identity
  * Add "image unset" command
  * Support X.latest format for OS_COMPUTE_API_VERSION
  * Fix i18n support for help and error msg in network
  * remove assert in favor an if/else
  * Fix some missing i18n support problems in compute
  * i18n support for help and error messages in cinder
  * include old release notes in reno
  * Devref: Command Beta
  * Avoid TypeError on message object additions
  * Additional network protocol support
  * Add network support for "quota set"
  * Fix --enable options on commands
  * Refactor TestRemoveProjectImage with FakeImage class
  * fix image unset
  * Add server set/unset unit test cases
  * Fix release note links to (now) external docs
- update _service and switch to upstream spec template
* Fri Mar  4 2016 tbechtold@suse.com
- update to 2.2.0:
  * Fix test_aggregate functional test
  * Updated from global requirements
  * Trivial: Reorder unit tests in alphabetical order in volume tests
  * [Image] Check return value is None in image unit tests
  * Support "network create" command in nova network
  * Devref: Options with Choices
  * Clean up unnecessary import of urlparse module
  * Trivial: Update image_list v2 docs
  * Fix regression in interactive client mode
  * Fix 'code-block' tag format issues
  * TrivialOrder: Rearrange Class Names
  * add a checklist for creating a new plugin
  * Trivial: Reorder flavor op order in flavor.py
  * Subnet: Add "subnet delete" command using SDK
  * fix: Exception message includes unnecessary class args
  * Refactor security group list to use SDK
  * take_action() method from command.Command shouldn't return
  * Trivial: Reorder unit tests in test_type.py
  * Fix return value of "image set" command
  * [Compute] Check return value is None in compute unit tests
  * Router: Add --route and --clear-routes options to "router set" command
  * Add MultiKeyValueAction to custom parser action
  * Make SetAggregate inherit from cliff.Command
  * Make SetAgent inherit from cliff.Command
  * Make SetSecurityGroup inherit from cliff.Command
  * Make SetFlavor and UnsetFlavor inherit from cliff.Command
  * Add missing command/configuration object
  * Updated from global requirements
  * Add shell --profile option to trigger osprofiler from CLI
  * update heat object and command doc
  * Add some test cases for "server list" command
  * Floating IP: Neutron support for "ip floating show" command
  * Improve tox to show coverage report on same window
  * Py3 replace dict.iteritems with six.iteritems
  * Updated from global requirements
  * Defaults are ignored with flake8
  * Fixed a bunch of spacing
  * Add "security group rule show" command
  * Fix wrong return value in TestDeleteFloatingIPNetwork
  * Use update_parser_common() in ShowNetwork
  * Use instanceof instead of type
  * Add "os subnet show" command using SDK
  * Initialize _keys in __init__() in FakeFlavorResource
  * Add unit tests for 'hypervisor stats' command
  * Clean redundant argument to dict.get
  * Add functional tests for "volume" commands v2
  * Add functional tests for "image" command v2
  * Updated from global requirements
  * Add unit test for "flavor show" command
  * Refactor: Set "project_id" for FakeXXX in a consistent style
  * Fix Mutable default argument
  * gitignore .idea
  * Trivial: Rename subnet_pool.rst to subnet-pool.rst
  * Replace string format arguments with function parameters
  * Support unscoped token request
  * Use assertIsNone() instead of assertEqual(None, xxx)
  * Don't use Mock.called_once_with that does not exist
  * Floating IP: Fix "ip floating list" in neutron network
  * Subnet Pool: Add "subnet pool show" command
  * Subnet Pool: Add "subnet pool list" command
  * Remove unused test-requirments
  * Subnet Pool: Add "subnet pool delete" command
  * Support "network show" command in nova network
  * Support "network list" command in nova network
  * Add release note for "network delete" command for nova network
  * Define FakeFloatingIP class in tests/compute for nova network commands
  * Add release note for "ip floating delete/list" commands for neutron network
  * Fix 'openstack --help' fails if clouds.yaml cannot be read
  * Rename parameter "identifier" to "network" in network commands
  * Use assertRaises() to check if an exception is raised
  * Support "network delete" command in nova network
  * Floating IP: Neutron support for "ip floating list" command
  * Floating IP: Neutron support for "ip floating delete" command
  * Updated from global requirements
  * Add quota functional tests
  * Add NetworkAndCompute Lister and ShowOne classes
  * Fix identity test_role functional tests
  * Trivial: Fix a typo in test_network.py
  * Updated from global requirements
  * Refactor network AZ exception handling
  * Refactor security group rule delete to use SDK
  * Identity: Fix DisplayCommandBase comments for cliff ShowOne subclass tests
  * Identity: Fix DisplayCommandBase comments for cliff Lister subclass tests
  * Identity: Fix DisplayCommandBase comments for cliff Command subclass tests
  * Trivial: Fix "abstractmethod" to "abstract method"
  * Fix DisplayCommandBase comments for cliff ShowOne subclass tests
  * Add "token revoke" for identity v3
  * Fix DisplayCommandBase comments for cliff Lister subclass tests
  * Fix DisplayCommandBase comments for cliff Command subclass tests
  * Updated from global requirements
  * Add release note for custom logging feature
  * Add release note for recursive delete
  * Add unit tests for "hypervisor show" command
  * Compute: Fix DisplayCommandBase comments for cliff ShowOne subclass tests
  * Compute: Fix DisplayCommandBase comments for cliff Lister subclass tests
  * Compute: Fix DisplayCommandBase comments for cliff Command subclass tests
  * Remove identity_client.projects definition in TestSecurityGroup
  * Define security_group_rules mock in FakeComputev2Client
  * Move security_groups mock definition to FakeComputev2Client
  * Fix formatting in release 2.0.0 notes
  * Fix some release note formatting
  * Add recursive object delete for containers
  * Refactor security group functional tests
  * Add functional tests for snapshots
  * Add support for triggering an crash dump
  * Add unit tests for "hypervisor list" command
  * Allow custom log levels for other loggers
- Adjust Requires according to requirements.txt
* Wed Mar  2 2016 tbechtold@suse.com
- Add python-openstacksdk as BuildRequires
* Wed Mar  2 2016 dmueller@suse.com
- update to 2.1.0:
  * Minor typo in help text
  * Fix a spell typos
  * Add --marker option to "image list" command
  * Add limit option to "image list" command
  * Remove marker and loop from "image list" command
  * Trivial: Reorder test class in test_volume.py into alphabetical order
  * Fix wrong type of volume attachments in FakeVolume
  * Refactor TestVolumeCreate to use FakeVolume
  * Refactor security group delete to use SDK
  * Add "os port show" command
  * Support listing network availability zones
  * Trivial: Fix wrong comment in test_image.py
  * Network: Abstract get_body() out to be a private helper
  * Drop log_method decorator
  * Updated from global requirements
  * Consume openstackclient.common.command in subnet/port
  * Fix showing network quotas for a project
  * Add missing release notes
  * log take_action parameters in a single place
  * Revert "Skip identity v2 functional tests"
  * Skip identity v2 functional tests
  * Add availability zone support for router commands
  * Update translation setup
  * Add availability zone support for network commands
  * Allow wait_for_delete to work for all clients
  * Updated from global requirements
  * Remove the Tuskar client
  * Use correct terminology for subnets
  * Updated from global requirements
  * Add releasenote for 'subnet list' command support
  * Add router functional tests
  * Subnet List
  * Updated from global requirements
  * Refactor abstract columns and datalist out in image and object test cases
  * Updated from global requirements
  * Refactor abstract columns and datalist out in compute test cases
  * log_method: get logger from decorated method if unspecified
  * Set up logger of each command by metaclass
  * Refactor: Abstract columns and datalist out in volume test cases
  * Add support to delete the ports
  * Initialize activation status
  * Imported Translations from Zanata
  * Updated from global requirements
  * Doc: Network is supported for extension object
  * Change --owner to --project in image commands
  * Support listing volume availability zones
  * Refactor "os availability zone list"
  * Changed the abstract columns and datalists from test cases of common and Identity
  * Updated from global requirements
  * Support non-interactive user password update
  * Use assertTrue/False instead of assertEqual(T/F)
  * Replace assertEqual(*, None) with assertIsNone in tests
  * Updated from global requirements
  * Further improve output for "os security group show"
  * Delete the unused LOG configure code
  * Refactor network endpoint enablement checking
* Sun Oct  4 2015 tbechtold@suse.com
- update to 1.7.1:
  * Release notes 1.7.1
  * docs: pip install -e needs an argument
  * Glance `image set` Resolve Fracturing
* Sat Sep 26 2015 tbechtold@suse.com
- update to 1.7.0:
  * Add release notes for 1.7.0
  * Use format_list instead of format_dict when listing images
  * Format an images properties and tags
  * Add image create support for image v2
  * Change ignore-errors to ignore_errors
  * Imported Translations from Zanata
  * Remove backticks from help in role commands
  * Move option logging back to start if initialize_app()
  * Set default auth plugin back to 'password'
  * Updated from global requirements
  * set image api to 1 for functional tests
  * Updated from global requirements
  * Imported Translations from Transifex
  * Use novaclient.client.Client for initialization Nova client
  * Add filtering by user for 'openstack server list'
  * Add support for listing servers of other projects
  * Support listing users by group name
  * Fix compute API version snafu
  * Properly handle port arguments for ICMP
  * Use a common decorator to log 'take_action' activation
  * Fix 'auhentication' spelling error/mistake
  * Volume v2 list does not show server name
  * Ignore flavor and image find errors on server show
  * Create log configuration class
  * default OS_VOLUME_API_VERSION to v2
  * Automate flavors, networks, and image get
  * unwedge the osc gate
  * additional functional tests for identity providers
  * Adds documentation on weekly meeting
  * Update the plugin docs for designate
  * Added note to install openstackclient
  * Running 'limits show' returns nothing
  * Optimize log formatting
  * Extract log level from configuration file
  * Move options to log level out of shell.py
  * Move set warnings filters to logging module
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Add tests for volume quota set
- Adjust Requires according to requirements.txt
* Mon Aug 31 2015 dmueller@suse.com
- update to 1.6.0:
  * Use correct domain to find project
  * Updated from global requirements
  * Skip functional test: test_server_up
  * Remove non-existing hacking deviations from doc
  * Update plugin documentation
  * Add release notes for 1.6.0
  * Add developer documentation
  * Add --inherited to the role docs
  * Rename command docs to remove underscores
  * Inherited info/option when listing role assignment
  * Alphabetize setup.cfg
  * Add set feature to volume type v2
  * Add list feature to volume v2
  * Fixes inherited role assignments CRUD calls
  * Fix quota show when there is no project id
  * Add functional test for volume type create --property
  * Imported Translations from Transifex
  * Added a new function test for volume type set
  * Introduce functional test for Identity Provider
  * Add domain scoping in 'role assignment list'
  * Removed unnecessary assignment of function result Joined lines together
  * New test for configuration show --mask
  * add new test for configuration show unmask
  * Minor Documentation changes for code samples
  * Set OS_VOLUME_API_VERSION before running functional tests
  * Added test for `volume type show`
  * Add functional tests for volume type list
  * New test for configuration show
  * Fix quota set failed problem
  * Add support for volume v2 commands
  * Add configuration show command
  * Add plugin interface version
  * Fix --os-auth-plugin in auth_with_unscoped_saml
  * add doc for floatingip
  * Fix yet more documentation warnings
  * Make trustee/trustor/project searchable by ID
  * Add create and list for volume type v2
  * add image member commands for image API
  * Fix the way auth_type default value is overriden
  * Format volume type properties when showing
  * Rename type.py to volume_type.py
  * Removes trailing blank in trust show
  * Add volume type show for volume v1
  * --property should be required in `os unset` commands
  * More minor docs fixes
  * Minor identity documentation change
  * Add functional tests server reboot
  * Add functional tests server IP attach and detach
  * Add details to the documentation
  * Making --property as required when openstack flavor unset
  * Do not set default versions in parsed args
  * Add functional tests for servers that require wait
  * enhance tests for user v3
  * Remove unnecessary test extension mock
  * Remove requirements.txt from tox.ini
  * add functional tests for identity v3
  * Add functional tests for volume qos
  * Support multiple volume qos delete
  * add functional tests for identity v2
  * add --project-domain option for user v3
  * only return endpoints that have url
  * Fix the way we call find_resource when only using ID
  * Fix image save with API v2
  * Rename endpoint type to interface
  * temporarily skip help tests
  * Drop py33 support for Liberty
  * Fix interactive password prompt
  * Fix wrong mock method call
  * add functional tests for identity v2
  * Fixes modules index generated by Sphinx
  * Fix address parsing for server ssh command
  * openstack catalog list always returns publicURL for internalURL and adminURL
  * Remove the --dhcp option to network list
  * Remove testing of cliff command line options
  * add functional tests for identity v3
  * Add --os-endpoint-type cli optional argument
  * Show which aggregate a hypervisor is member of
  * Move update code from image create command
  * Fix examples with cacert
  * Add support for volume API v2 QoS commands
  * Add tests for 'list' and 'show' for volume qos v1
  * Alphabetize tests for v1 qos_specs
  * Add docs for QoS specs
  * No need for get_parser on QoS list
  * Alphabetize QoS specs
  * Add support for volume API v1 QoS commands
  * fix confused domain argument for network create v2
  * fix typo in network.rst
  * Add support to inherited project role grant calls
  * fix typo for server create in server.rst
  * Fix typo in user.rst
  * Update 1.4.0 release notes
  * Refactor option handling for user|group|project domain scoping
* Mon Jul 20 2015 dmueller@suse.com
- update to 1.5.0:
  * Add release notes for 1.5.0
  * reference corect ec2 helper function
  * Updated from global requirements
  * Improve the hint message
  * Fix the typo in `openstackclient/shell.py`
  * Add oidc plugin for listing federation projects
  * Skip trying to set project_domain_id if not using password
  * Updated from global requirements
  * Updated from global requirements
  * Imported Translations from Transifex
  * Include links to developer workflow documentation
  * Enable specifying domain for group and role commands
  * Not use the deprecated argument
  * Create 1.4.0 release notes
  * Updated from global requirements
  * Add support for volume snapshot v2 command
  * Allow --insecure to override --os-cacert
  * Clean up ec2 credentials help text
  * Add functional tests for volume set and unset
  * Add domain support for ec2creds in v3 identity
  * Add EC2 support for identity v3 API
  * Imported Translations from Transifex
  * Add a reference to the IRC channels
  * Change Credentials header to Blob from data
  * Get rid of oslo_i18n deprecation notice
  * Fix security group list command
  * Rework shell tests
  * Add image functional tests
  * Add volume functional tests
  * Ignore cover directory from git
  * Set tenant options on parsed namespace
  * Add support for volume v2 API
  * add domain scope arguments to v3 role add in doc
  * project create is missing --parent in doc
  * add --domain argument to v3 project set
  * Add --wait to server delete
  * Use ostestr for test runs
  * Add cli tests for --verify and friends
  * Small tweaks to osc plugin docs
  * Fix shell tests
  * Create 1.3.0 release notes
  * Add support for v2 image set command
  * Adds python-tuskarclient to list of plugins
  * Remove oslo serialization requirement
  * Remove oslo incubator config
  * Add missing properties to image set command
  * Add some comments about current plugin support
  * Remove checks for None dates in keypair functional tests
  * Fix client error while rescuing an instance
  * Add support for keypair functional tests
  * Fix insecure/verify options
  * Use format options for functional tests
  * Fix functional test gate
  * Updated from global requirements
  * Enable specifing domains in "role add"
  * Send the correct user-agent to Keystone
  * Updated from global requirements
  * Security group rule delete broken
  * Updated from global requirements
  * Imported Translations from Transifex
  * Don't create empty quota set requests
  * Updated from global requirements
  * Add os-client-config cli tests
  * minor syntax error in tox.ini
  * Add image show tests
  * Minor fix to openstack image show command
  * Create 1.2.0 release notes
  * Fix tiny typo in comment message
  * Minor logging/debug cleanups
  * Redo 1.1.0 release notes
  * Remove unique class names because they are scoped
  * Raise exception if no session is created
  * Reduce parameters to base class execute
  * Functional tests run in many environments
  * Remove references to venv
  * Add a doc that dictates backwards incompatible changes
  * Remove run_tests.sh
  * Security group rule create fails
  * Fix security group create description bug
  * Adds support for container selection for backup
  * Create 1.1.0 release notes
  * Handle the pagination for image list
  * Refactor utility to find identity resources
  * Imported Translations from Transifex
  * remove unnecessary conditionals
  * Update the docs for new nic options
  * Begin documenting --os-cloud
  * Add --os-cloud support
  * Imported Translations from Transifex
  * Re-organize functional tests
  * Role operations should not require list object permission
  * Print warning on authentication error
  * Fix skipped image create attribute location attr
  * Uncap library requirements for liberty
  * Defer client imports
  * Better help for --nic in create server
  * Add support to specify volume quotas per volume type
  * Add docs for service provider CRUD
  * Federation Service Providers CRUD operations
  * Add warning message if unknown version supplied
  * Fix session timing
  * Add support for showing limits of a specific project
  * Suppress warnings user can't fix
  * Use glanceclient's inbuilt images find
  * Updated from global requirements
  * Imported Translations from Transifex
  * Add support to remote_id
  * Add parent field to project creation
  * Add project and domain params to network create
  * Add a doc about authenticating against v3
  * Add the ability to set and unset flavor properties
  * Use cliff deferred help instead of homemade one
  * Base TokenEndpoint plugin on keystoneclient's
- remove 0001-Fix-image-create-location-attribute.patch
* Fri Jun 12 2015 mjura@suse.com
- Add 0001-Fix-image-create-location-attribute.patch, bnc#932270
* Fri Apr 24 2015 tbechtold@suse.com
- Use %%{version} in source
* Thu Apr 23 2015 tbechtold@suse.com
- Switch to version 1.0.3
* Wed Apr 22 2015 tbechtold@suse.com
- Add missing Requires for python-oslo.config
* Wed Apr 22 2015 tbechtold@suse.com
- Update to version python-openstackclient-1.0.3.post52:
  * Handle the pagination for image list
  * Imported Translations from Transifex
  * remove unnecessary conditionals
  * Update the docs for new nic options
  * Begin documenting --os-cloud
  * Add --os-cloud support
  * Role operations should not require list object permission
  * Defer client imports
  * Add support for showing limits of a specific project
* Sat Apr 18 2015 cloud-devel@suse.de
- Update to version python-openstackclient-1.0.3.post35:
  * Imported Translations from Transifex
  * Print warning on authentication error
  * Suppress warnings user can't fix
* Fri Apr 17 2015 cloud-devel@suse.de
- Update to version python-openstackclient-1.0.3.post29:
  * Re-organize functional tests
  * Fix skipped image create attribute location attr
  * Uncap library requirements for liberty
  * Better help for --nic in create server
  * Fix session timing
* Fri Apr 17 2015 cloud-devel@suse.de
- Update to version python-openstackclient-1.0.3.post20:
  * Add support to specify volume quotas per volume type
* Wed Apr 15 2015 cloud-devel@suse.de
- Update to version python-openstackclient-1.0.3.post18:
  * Add warning message if unknown version supplied
  * Use cliff deferred help instead of homemade one
* Tue Apr 14 2015 cloud-devel@suse.de
- Update to version python-openstackclient-1.0.3.post14:
  * Use glanceclient's inbuilt images find
* Thu Apr  2 2015 cloud-devel@suse.de
- Update to version python-openstackclient-1.0.3.post13:
  * Updated from global requirements
* Wed Apr  1 2015 cloud-devel@suse.de
- Update to version python-openstackclient-1.0.3.post11:
  * Imported Translations from Transifex
  * Add support to remote_id
* Tue Mar 24 2015 cloud-devel@suse.de
- Update to version python-openstackclient-1.0.3.post8:
  * Add project and domain params to network create
  * Add a doc about authenticating against v3
  * Add the ability to set and unset flavor properties
* Fri Mar 13 2015 cloud-devel@suse.de
- Update to version python-openstackclient-1.0.3.post3:
  * Look harder to find DevStack
* Thu Mar 12 2015 cloud-devel@suse.de
- Update to version python-openstackclient-1.0.3.post1:
  * Base TokenEndpoint plugin on keystoneclient's
* Wed Mar 11 2015 cloud-devel@suse.de
- Update to version python-openstackclient-1.0.3:
  1.0.3
  * Create 1.0.3 release notes
  * Move OSC auth plugins so they can be found
  * Add identity v3 catalog show
  * Update README
  * Imported Translations from Transifex
  * Add identity v3 catalog list
  * Fix catalog list when region name is absent
  * Add ability for diplaying hypervisor statistics
  * Add 'uptime' in 'hypervisor show'
  * Raise AttributeError for unknown attributes
  * Add hypervisor docs
  * Don't hack the image url
  * Fix embarrassing typo in man page
  * Updated from global requirements
  * Fix identity v2 catalog list
  * Fix help messages
  * Handle novaclient >2.20.0
  * Rename --verify for server resize to avoid conflict
* Tue Mar  3 2015 cloud-devel@suse.de
- Update to version python-openstackclient-1.0.2.post50:
  * Fix auth-required for help command
  * Fix error msg in sort_items
* Fri Feb 27 2015 cloud-devel@suse.de
- Update to version python-openstackclient-1.0.2.post46:
  * change oslo namespace to avoid warning
  * Revert "Skip functional tests until they are fixed"
* Thu Feb 26 2015 cloud-devel@suse.de
- Update to version python-openstackclient-1.0.2.post42:
  * Updated from global requirements
* Wed Feb 11 2015 cloud-devel@suse.de
- Update to version python-openstackclient-1.0.2.post41:
  * Skip functional tests until they are fixed
  * Restrict groups and users from changing domains
  * Do not allow user to change domain of a project
  * Implement trust in identity v3 api
* Sun Feb  8 2015 cloud-devel@suse.de
- Update to version python-openstackclient-1.0.2.post34:
  * Imported Translations from Transifex
  * Change volume create --snapshot-id to --snapshot
  * Add sort support to image list
* Sat Feb  7 2015 cloud-devel@suse.de
- Update to version python-openstackclient-1.0.2.post29:
  * Check volume status before extending size
  * Adding default user_domain_id parameter only when using password auth
  * Added capabilities/options to 'openstack flavor list' command to match capabilities already provided by 'nova flavor-list':
  * Add network support to quota show
  * Begin low-level API for Network v2
* Fri Feb  6 2015 cloud-devel@suse.de
- Update to version python-openstackclient-1.0.2.post19:
  * tenant_id to project_id in server show
* Tue Feb  3 2015 cloud-devel@suse.de
- Update to version python-openstackclient-1.0.2.post18:
  * Improving the help of the lock command
* Fri Jan 30 2015 cloud-devel@suse.de
- Update to version python-openstackclient-1.0.2.post16:
  * Updated from global requirements
* Thu Jan 29 2015 cloud-devel@suse.de
- Update to version python-openstackclient-1.0.2.post15:
  * Change test order to avoid incompatibliity
  * Add filter to image list
  * Add the ability to extend volumes in `osc volume set`
* Wed Jan 28 2015 cloud-devel@suse.de
- Update to version python-openstackclient-1.0.2.post10:
  * fix the wrong order of assertEqual args
  * Add 'find by name' to --nic for creating server
* Tue Jan 27 2015 cloud-devel@suse.de
- Update to version python-openstackclient-1.0.2.post7:
  * Remove ignore portion of tox.ini
* Sun Jan 25 2015 cloud-devel@suse.de
- Update to version python-openstackclient-1.0.2.post6:
  * fix object list command naming
* Fri Jan 23 2015 cloud-devel@suse.de
- Update to version python-openstackclient-1.0.2.post5:
  * Command docs: network
* Thu Jan 22 2015 cloud-devel@suse.de
- Update to version python-openstackclient-1.0.2.post3:
  * Add region name for identity and volume clients
  * Begin low-level API for Image v1 and v2
* Tue Jan 20 2015 cloud-devel@suse.de
- Update to version python-openstackclient-1.0.2:
  1.0.2
  * Fix doc building errors
  * Create 1.0.2 release notes
  * Imported Translations from Transifex
  * Add version url config workaround
* Mon Jan 19 2015 cloud-devel@suse.de
- Update to version python-openstackclient-1.0.1.post122:
  * Add missing oslo-config to requirements
* Sat Jan 17 2015 cloud-devel@suse.de
- Update to version python-openstackclient-1.0.1.post121:
  * Update service clist commands for v2 and v3
  * Default user domain id and project domain id
  * Add helpful messages when authN'ing with password
* Fri Jan 16 2015 cloud-devel@suse.de
- Update to version python-openstackclient-1.0.1.post115:
  * Use session for neutron client
  * Imported Translations from Transifex
  * Deprecate project usage list command
  * Copy wiki content to index page
  * Copy HIG from wiki
  * Check if service.name available before access
* Wed Jan 14 2015 tbechtold@suse.com
- Update to version python-openstackclient-1.0.1.post104:
  * Tweaks to the catalog doc and show command
  * Fine tune some of the helps commands
  * Command doc: policy
  * Updated from global requirements
  * Upgrade hacking to 0.10
  * Command docs: add service
  * fix some small issues in catalog show
  * Rework role list v2 for --user and --project
  * Add versioning to the docs that missed it
  * Updated from global requirements
  * Command doc: access token
  * Request token authorize
  * Command doc: snapshot
  * Fix up snapshot command
  * Command doc: image
  * Request token creation docs + tweaks
  * Command doc: consumer
  * Allow user list to filter by project
  * Command doc: federation protocol
  * Command doc: identity provider
  * Command doc: mapping
  * Command doc: backup
  * Fixup backup list output
  * Command docs: volume
  * Update the command list
  * Command doc: volume type
  * tweak the server command docs
  * Command docs: group
  * Add endpoint v3 docs
  * Command docs: ec2 credentials
- Adjust Requires according to requirements.txt
* Wed Dec 10 2014 cloud-devel@suse.de
- Update to version python-openstackclient-1.0.1.1.g52d2235:
  * Tweaks after the fact
* Tue Dec  9 2014 cloud-devel@suse.de
- Update to version python-openstackclient-1.0.1:
  1.0.1
  * Release 1.0.1
* Sun Dec  7 2014 cloud-devel@suse.de
- Update to version python-openstackclient-1.0.0.5.g8b9f45c:
  * Followup for ec2 credentials command fix
* Sat Dec  6 2014 cloud-devel@suse.de
- Update to version python-openstackclient-1.0.0.3.g95b1853:
  * Fix ec2 credentials commands for new auth
  * Workflow documentation is now in infra-manual
* Fri Dec  5 2014 cloud-devel@suse.de
- Update to version python-openstackclient-1.0.0:
  1.0.0
  * Command object docs: catalog, credentials, endpoint, region, token
  * Safely pop project parent id
  * Add documentation of interactive mode
  * 1.0.0 release notes
  * Command object docs: server, server image
* Wed Dec  3 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.4.1.157.gcc54f98:
  * Add the ability to list projects based on a user
* Tue Dec  2 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.4.1.155.g2663e16:
  * Add support for domains when deleting identity v3 resources
  * Command object docs: project, role, user
  * Updated from global requirements
  * Command object docs: aggregate, console *, keypair
  * Begin copying wiki command list here
  * Enhance the theming for modules page
* Sat Nov 22 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.4.1.143.ga2450d8:
  * Liberalize version matching a bit
* Thu Nov 20 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.4.1.141.gae00019:
  * Fix volume create --image
  * add keystone v3 region object
  * Updated from global requirements
  * Add --or-show support for v3 identity resources
  * Add authentication description doc
  * Add environment variable in the os-auth-type help
  * Add more session/api examples
  * Add an API example base and functional test base
  * Add arg to 'server image create' tests
  * Add additional support for --or-show
* Sat Nov 15 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.4.1.122.gf5a2811:
  * Remove links from oauth consumers
  * Remove links from federation related commands in identity v3
  * cleanup files that are created for swift functional tests
  * Beef up object-store tests
* Thu Nov 13 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.4.1.114.gb8d8e35:
  * Tests work fine with random PYTHONHASHSEED
  * Use fixtures from keystoneclient for static data
* Tue Nov 11 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.4.1.110.gc8ddfd8:
  * Swap remaining assertEqual arguments
  * Add --or-show option to user create
* Mon Nov 10 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.4.1.106.g951ca3a:
  * Updated from global requirements
* Sat Nov  8 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.4.1.105.g59735bf:
  * Add cliff-tablib to requirements
* Thu Nov  6 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.4.1.104.g631ed3c:
  * Unscoped federated user-specific commands
* Mon Oct 27 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.4.1.103.g2c9d263:
  * Fix server create for boot-from-volume
  * Adjust some logging levels
  * Change --os-auth-plugin to --os-auth-type
  * Include support for using oslo debugger in tests
  * Clean up shell authentication
  * Fix token issue after auth changeup
  * only generate one clientmanager instance in interactive mode
  * Remove ClientManager._service_catalog
  * Remove now-unnecessary client creation hacks
  * use jsonutils in oslo.serialization instead of keystoneclient
  * Close files on server create, add tests
  * Close files on image create
  * Move plugin stuff to clientmanager
  * Update use of open() in object API
  * Add plugin to support token-endpoint auth
* Wed Oct 15 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.4.1.78.gfa9cdef:
  * Put pbr and six first in requirements list
  * Fix operation on clouds with availability-zones
  * Add 'command list' command
* Tue Oct 14 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.4.1.72.g79a9331:
  * Remove 'links' section from several v3 Identity objects
  * Fix issue token for v3
  * Updated from global requirements
  * Add translation markers for user v2 actions
  * Mark identity v2 resources for translation
  * Update compute server messages for translation
* Sun Oct 12 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.4.1.60.gf0c57e1:
  * Allow --domain to be used for identity commands without lookup
  * Add domain parameters to user show for Identity V3
* Fri Oct 10 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.4.1.58.g0c77a9f:
  * Support for keystone auth plugins
  * CRUD operations for federated protocols
  * Update for cliff commandmanager >=1.6.1
  * Pass in domain and project as positional args, not kwargs
* Thu Oct  9 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.4.1.51.gd405b1b:
  * Implement CRUD operations for Mapping objects
  * Fix issues with object related commands
* Tue Oct  7 2014 dmueller@suse.com
- Update to version python-openstackclient-0.4.1.47.g0cb204e:
  * Update gitignore
  * Add some code-blocks to the docs
  * Place the command to generate docs on one line
  * Remove duplicate env function in shell.py
  * Create a whole slew of functional tests for identity
  * Add functional tests to osc
  * Move object-store commands to low-level API
  * Add low-level API base class
  * Test top-to-bottom: object-store containers
* Mon Sep 29 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.4.1.34.g02320a5:
  * Updated from global requirements
  * utils.find_resource does not catch right exception
* Thu Sep 25 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.4.1.30.g1212ddb:
  * Remove unused reference to keyring
* Tue Sep 23 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.4.1.29.g2d12256:
  * v3 credential set always needs --user option
  * Use oslo.utils
* Mon Sep 22 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.4.1.27.gceae0be:
  * Change help text for image save command
  * Fixing typo and improving docstring of find_domain
* Mon Sep 22 2014 tbechtold@suse.com
- Update to version python-openstackclient-0.4.1.24.g2a2c8ee:
  * Updated from global requirements
  * Acknowlege git.o.o as OpenStack's git server
  * Add service catalog commands
  * Return current user/project for user/project show commands
  * Add support for 'file' format objects
  * Add preliminary save container support
  * Add preliminary support for downloading objects
  * Stop using intersphinx
  * Updated from global requirements
  0.4.1
  * Use Keystone client session.Session
  * Multiple args for object and container commands
  * Work toward Python 3.4 support and testing
  * Add network extension list
* Tue Sep  9 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.4.0.113.g696c967:
  * Update docs and release notes for 0.4.1 release
  * Add action 'user password set' for identiy v3
  * Unordered dicts and lists causes variable results
  * Leverage openstack.common.importutils for import_class
  * Sync with oslo-incubator and add importutils
  * assertEquals order wrong
  * Make Identity client load like the others
  * Fix server add security group
  * Fix security group list for non-admin
  * Change app.restapi to app.client_manager.session
  * Network use enable/disable vs admin state up/down
  * add service/interface/region filter for endpoint v3
* Tue Aug 26 2014 tbechtold@suse.com
- Update BuildRequires and Requires
* Sun Aug 24 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.4.0.89.g1eb7aba:
  * Add i18n module to openstackclient
  * Create message variables for exceptions
  * Add oslo.i18n as a dependency
* Sat Aug 23 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.4.0.83.g7a8c9a7:
  * Updated from global requirements
  * add tests for identity v3 endpoint
* Fri Aug 22 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.4.0.80.gfc44578:
  * add tests for identity v3 domain
* Wed Aug 13 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.4.0.78.g19b8605:
  * a mistake in tests/identity/v3/test_role.py
  * Add commands for object upload and delete
* Mon Aug 11 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.4.0.75.g0cfd0b1:
  * test_find_resource fails if run alone
  * Use oslosphinx to generate documentation
  * user create v2.0 depends on tenantId in response
  * Updated from global requirements
  * v3 endpoint set shouldn't always need service option
  * Add container create and delete support
* Sat Aug  2 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.4.0.64.g75e8490:
  * Cleanup README.rst
* Wed Jul 30 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.4.0.63.g81d1179:
  * fix typo in identity/v3/endpoint.py
* Tue Jul 29 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.4.0.62.g02cdebb:
  * More make_client() logging cleanup
  * Add more columns to image list output
* Fri Jul 25 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.4.0.58.g01f7a5f:
  * Change V2 image tests to actually run V2 image code
* Thu Jul 24 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.4.0.56.ge0cf68f:
  * Normalize more help strings
* Thu Jul 24 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.4.0.54.g8c556e6:
  * Fix PEP8 E302 errors
  * Change object API_NAME to 'object_store'
* Tue Jul 22 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.4.0.51.g4d3d287:
  * Fix IDP commands
  * Update help text for some network commands
* Thu Jul 17 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.4.0.48.g3cfb97e:
  * Add Python 3 support
* Sat Jul 12 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.4.0.47.g5830007:
  * Fix server resize
* Fri Jul 11 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.4.0.45.gbc6495c:
  * Add basic timing support
* Wed Jul  9 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.4.0.43.g7028374:
  * Domain administrator cannot do project operations
  * Allow network find to use alternate name
  * Add support to list volume extensions
* Tue Jul  8 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.4.0.37.gba15646:
  * Clean up make_client() logging
  * Python 3: do not compare a list to a zip object
  * Catch SystemExit for parse args
  * Python 3: remove a useless code to safe_encode()
  * Add support to list compute extensions
* Mon Jul  7 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.4.0.27.gea938e8:
  * Replaced some UTF-8 characters with ASCII characters
  * Move network stuff to v2 instead of v2_0
* Fri Jul  4 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.4.0.24.gb3736fd:
  * Remove keyring support from openstackclient
  * trust authentication
  * Python 3: do not use __builtin__
* Thu Jul  3 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.4.0.18.g8e12949:
  * Updated from global requirements
  * Remove backslash usage from a few tests
* Sat Jun 28 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.4.0.15.gddf0c16:
  * Sort/clean setup.cfg
  * Rename token classes to match command
  * Fix PEP8 E126 and E202 errors
  * Fix PEP8 E265 errors
  * Fix PEP8 H405 errors
  * Fixed typos in the identity client
* Thu Jun 26 2014 dmueller@suse.com
- Update to version python-openstackclient-0.4.0.4.g8f59524:
  * Network CRUD
  * Updated from global requirements
  * sync oslo bits
  0.4.0
  * Update docs and release notes for 0.4.0
  * Updated from global requirements
  * Complete Identity v3 list command filters
  * Change the token verb to issue/revoke
  * Update docs template
  * Add a docs job to tox.ini
  * Fix find_resource for keystone and cinder
  * Refactor role list subcommand for identity v3 api
  * Add token delete command for identity v2
* Tue Jun 24 2014 dmueller@suse.com
- add python_requires service
* Wed Jun 18 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.3.1.67.g6380b8b:
  * Image create and set command updates and tests
  * Refactor oauth1 code for updates
* Tue Jun 17 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.3.1.64.gfbb9e7a:
  * Clean up logging levels
* Mon Jun 16 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.3.1.62.g5c2d9f3:
  * Updated from global requirements
* Sun Jun 15 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.3.1.60.g0da5bfe:
  * Ignore most of the new hacking 0.9.2 rules
  * Add support for extension list
* Sat Jun 14 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.3.1.56.g497a389:
  * Add role assignments list support to identity v3
* Wed Jun 11 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.3.1.54.g7f6a901:
  * replace string format arguments with function parameters
  * Add tests for identity endpoints
* Thu May 29 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.3.1.50.gfb65652:
  * Fixed several typos throughout the codebase
  * Fix server image create
* Fri May 16 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.3.1.46.g870e7dd:
  * Change volume create --volume-type to --type
* Sat May 10 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.3.1.45.ga93851d:
  * Implement CRUD operations for Identity Providers
* Thu May  8 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.3.1.43.g03b9a72:
  * Display all server log when --lines option is None
  * Fix help message for `ip floating delete`
* Wed May  7 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.3.1.40.g834867b:
  * volume type create should display properties
  * Skip auth in cinderclient
* Sat May  3 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.3.1.37.g6c5f2e3:
  * Updated from global requirements
* Wed Apr 23 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.3.1.36.gc744abd:
  * Updated from global requirements
  * Fix the project option to user list so it filters
  * Make endpoint commands more consistent
* Fri Apr 18 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.3.1.30.g8ec78a1:
  * Pass arguments to v3 keystoneclient by kwarg
  * Make bash comple command best effort to authorize
  * In anticipation of network agents, rename compute
* Wed Apr 16 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.3.1.24.g01db6d9:
  * move read_blob_file_contents to utils
* Mon Mar 24 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.3.1.23.gee22070:
  * Correct display of project/tenant id on display of credentials
* Sun Mar 23 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.3.1.21.g4900c64:
  * Produce a useful error message for NoUniqueMatch
* Fri Mar 14 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.3.1.20.g0c0803d:
  * identity v3 allow project list filtering by domain
  * Add ability to set key value pairs in projects
* Thu Mar 13 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.3.1.17.g65f094e:
  * Updated from global requirements
* Tue Mar 11 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.3.1.16.gcf8506d:
  * Fix 'keypair show' command output
* Mon Mar 10 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.3.1.14.g4632238:
  * add interface and url to endpoint list
  * Fixed spelling error, compatability to compatibility
  * Fixed Spelling errors - compatability to compatibility
  * Fixed spelling errors - occurance to occurence
  * Updated from global requirements
  * Add --volume option to image create command
  0.3.1
* Sat Mar  1 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.3.0.50.g808fa65:
  * Update release notes for 0.3.1
  * Fix format errors in nova security group rule list
* Thu Feb 27 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.3.0.46.gb7f673c:
  * Use cacert values when creating identity client
  * Fix volume commands with multiple regions
* Tue Feb 25 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.3.0.43.g1253932:
  * Updated from global requirements
* Mon Feb 24 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.3.0.42.g8fe50fc:
  * Fix some help strings
* Sun Feb 23 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.3.0.40.g034a9d1:
  * Add ability to prompt for passwords for user create and set
* Sat Feb 22 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.3.0.38.g8b494f0:
  * Update oslo incubator bits
  * Rename Openstack to OpenStack
* Fri Feb 21 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.3.0.34.g2958421:
  * Python 3: the content of a FakeResponse must be bytes
  * Glance client no longer isa http client
* Fri Feb 14 2014 speilicke@suse.com
- Run testr directly
* Wed Feb 12 2014 cloud-devel@suse.de
- Update to version python-openstackclient-0.3.0.31.g2f5e823:
  * FakeResponse: use a default status code
  * Python 3: fix a syntax error
  * Fix misspellings in python openstackclient
* Tue Feb 11 2014 speilicke@suse.com
- Replace git_tarballs source service with download_files and set_version
  + Use upstream URL as source (enables verification)
* Sat Feb  1 2014 opensuse-cloud@opensuse.org
- Update to version 0.3.0.22.g6323633:
  + Add token create subcommand for identity v3 api
* Thu Jan 30 2014 opensuse-cloud@opensuse.org
- Update to version 0.3.0.20.g0aeb357:
  + Fix keyring issue where there were name space problems
  + Updated from global requirements
* Fri Jan 24 2014 opensuse-cloud@opensuse.org
- Update to version 0.3.0.17.gcb2fd0a:
  + Add token create subcommand for identity v2 api
  + Remove remaining print statements
  + Remove copyright from empty files
* Sat Jan 18 2014 opensuse-cloud@opensuse.org
- Update to version 0.3.0.11.g81d33a5:
  + Fix image set properties error
  + Sync with global requirements
* Sat Jan 11 2014 opensuse-cloud@opensuse.org
- Update to version 0.3.0.8.gb00bbaa:
  + Displaying curl commands for nova and cinder calls
  + Fix errant underscores
* Thu Jan  9 2014 opensuse-cloud@opensuse.org
- Update to version 0.3.0.4.ge821a6b:
  + Add support for specifying custom domains
* Thu Jan  2 2014 opensuse-cloud@opensuse.org
- Update to version 0.3.0.2.g202c3e3:
  + Closes-Bug: #1262322 Make links clickable
* Sat Dec 21 2013 opensuse-cloud@opensuse.org
- Update to version 0.3.0.1.g12f31ee:
  + Release notes for 0.3.0 release
  + Closes-Bug: #1262321
* Wed Dec 18 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.2.37.g4595ca1:
  + Remove mox3 requirement
* Wed Dec 11 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.2.36.gc645049:
  + Updated from global requirements
* Sat Dec  7 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.2.35.gfacdc87:
  + Update docs for plugins and release notes
  + Bring RESTApi closer to ithe imminent keystoneclient.Session
* Fri Dec  6 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.2.31.gb88a7b8:
  + Update OSC's CommandManager subclass
  + Add missing requests and six requirements
  + Add module list command
* Wed Dec  4 2013 speilicke@suse.com
- Run testsuite during build (%%check section) and obsolete the test
  package. An overall simplification of the test process
- Fixed totally broken dependencies
* Tue Dec  3 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.2.26.g5dcc3b6:
  + Add return Closes-Bug: 1246356
* Tue Nov 26 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.2.25.g935781f:
  + Restore Object API name 'object-store'
* Mon Nov 25 2013 dmueller@suse.com
- switch to python-setuptools
* Sat Nov 23 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.2.24.g9062811:
  + Expand support for command extensions
* Thu Nov 21 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.2.23.gd45187a:
  + Support building wheels (PEP-427)
  + Fix typo
  + change execute to run
  + Complete basic test infrastructure
  + Add server image create command
* Tue Nov 12 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.2.14.gc946192:
  + Update URL for global hacking doc and fix typos
* Sat Nov  9 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.2.13.ge118f21:
  + Remove httpretty from test requirements
  + Updated from global requirements
* Tue Oct 29 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.2.10.g9137cc3:
  + Do lookups for user, project in volume create
* Sun Oct 27 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.2.9.g1fa1330:
  + Adjust to non-deprecated names in Keyring 1.6.+
* Sun Oct 27 2013 dmueller@suse.com
- remove 0001-Adjust-to-non-deprecated-names-in-Keyring-1.6.patch
* Thu Oct 24 2013 dmueller@suse.com
- add 0001-Adjust-to-non-deprecated-names-in-Keyring-1.6.patch
- fix requires
* Thu Oct 17 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.2.8.ga1bda21:
  + Updated from global requirements
* Mon Oct 14 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.2.7.g29642c2:
  + Add options to support TLS certificate verification
  + Add to clientmanager tests
  + Sync oslo-incubator for py33 fixes
* Tue Oct  8 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.2.2.gbca4cf9:
  + Updated from global requirements
* Mon Sep 30 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.2.1.gad59b03:
  + Add object-store show commands
* Sat Sep 21 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.1.19.g74f4e31:
  + Fix security group entrypoints
  + Sort entrypoints in setup.cfg
  + Update release notes for 0.2.2
* Mon Sep 16 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.1.16.g6fe687f:
  + Delay authentication to handle commands that do not require it
* Wed Sep 11 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.1.15.g8898e02:
  + Update tox.ini for new tox 1.6 config
  + Prepare for Identity v3 tests
  + Identity v3 tests
* Thu Sep  5 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.1.11.g44c97cc:
  + Update requirements.txt and test-requirements.txt
  + Refactor fake data for projects and users
  + Add Identity v2 role and service tests
* Sat Aug 31 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.1.7.g725e254:
  + Object API commands using our REST API layer
* Thu Aug 29 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.1.6.g17f13f7:
  + Create a new base REST API interface
* Fri Aug 23 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.1.5.gb440986:
  + Re-order oauth commands and sync with keystoneclient
* Thu Aug 22 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.1.3.g22a6e88:
  + Add Identity v2 user tests
* Tue Aug 20 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.1.2.g493339d:
  + Add Identity v2 project tests
* Wed Aug  7 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.1:
  + Sync with global requirements
  + Add release notes in docs
* Fri Aug  2 2013 opensuse-cloud@opensuse.org
- Update to version 0.2.rc1.2.gaf87489:
  + Modify run_tests.sh to just run tox
  + Change version reporting to use pbr
* Thu Aug  1 2013 speilicke@suse.com
- Only require discover on SLE
* Fri Jul 12 2013 naehring@b1-systems.de
- added python-keyring to requires
* Tue Jul  2 2013 dmueller@suse.com
- fix requires
* Wed Jun 26 2013 dmueller@suse.com
- Initial package
